@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2018 Tom Schindl and others.
+ * Copyright (c) 2010, 2022 Tom Schindl and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -66,7 +66,6 @@ import org.w3c.dom.css.CSSStyleDeclaration;
 
 public class ThemeEngine implements IThemeEngine {
 	private List<Theme> themes = new ArrayList<>();
-	private Map<String, List<String>> themesToVarients = new HashMap<>();
 	private List<CSSEngine> cssEngines = new ArrayList<>();
 
 	// kept for theme notifications only
@@ -78,6 +77,7 @@ public class ThemeEngine implements IThemeEngine {
 	private List<IResourceLocator> globalSourceLocators = new ArrayList<>();
 
 	private HashMap<String, List<String>> stylesheets = new HashMap<>();
+	private HashMap<String, List<String>> stylesheetPluginExtensions = new HashMap<>();
 	private HashMap<String, List<String>> modifiedStylesheets = new HashMap<>();
 	private HashMap<String, List<IResourceLocator>> sourceLocators = new HashMap<>();
 
@@ -87,12 +87,13 @@ public class ThemeEngine implements IThemeEngine {
 
 	public static final String E4_DARK_THEME_ID = "org.eclipse.e4.ui.css.theme.e4_dark";
 
+	public static final String DISABLE_OS_DARK_THEME_INHERIT = "org.eclipse.e4.ui.css.theme.disableOSDarkThemeInherit";
+
 	public ThemeEngine(Display display) {
 		this.display = display;
 
 		IExtensionRegistry registry = RegistryFactory.getRegistry();
-		IExtensionPoint extPoint = registry
-				.getExtensionPoint("org.eclipse.e4.ui.css.swt.theme");
+		IExtensionPoint extPoint = registry.getExtensionPoint(THEME_PLUGIN_ID);
 
 		//load any modified style sheets
 		Location configLocation = org.eclipse.core.runtime.Platform.getConfigurationLocation();
@@ -112,41 +113,42 @@ public class ThemeEngine implements IThemeEngine {
 
 		File[] modifiedFiles = modDir.listFiles();
 		String currentOS = Platform.getOS();
-		String currentWS = Platform.getWS();
+		boolean e4_dark_mac_found = false;
+
 		for (IExtension e : extPoint.getExtensions()) {
-			for (IConfigurationElement ce : e.getConfigurationElements()) {
+			for (IConfigurationElement ce : getPlatformMatches(e.getConfigurationElements())) {
 				if (ce.getName().equals("theme")) {
 					try {
 						String id = ce.getAttribute("id");
 						String os = ce.getAttribute("os");
 						String version = ce.getAttribute("os_version");
 
-						if (version == null) {
-							version ="";
-						} else {
-							// For e4 dark theme on Mac, register the theme with matching OS version only
-							if (E4_DARK_THEME_ID.equals(id) && Platform.OS_MACOSX.equals(currentOS) && os != null
-									&& os.equals(currentOS)) {
-								if (!isOsVersionMatch(version)) {
-									continue;
-								} else {
-									version = "";
-								}
+						/*
+						 * Code to support e4 dark theme on Mac 10.13 and older. For e4 dark theme on
+						 * Mac, register the theme with matching OS version if specified.
+						 */
+						if (E4_DARK_THEME_ID.equals(id) && Platform.OS_MACOSX.equals(currentOS) && os != null
+								&& os.equals(currentOS)) {
+							// If e4 dark theme on Mac was already registered, don't try to match or
+							// register again.
+							if (e4_dark_mac_found) {
+								continue;
 							}
+							if (version != null && !isOsVersionMatch(version)) {
+								continue;
+							} else {
+								e4_dark_mac_found = true;
+								version = "";
+							}
+						}
+
+						if (version == null) {
+							version = "";
 						}
 
 						final String themeBaseId = id + version;
 						String themeId = themeBaseId;
 						String label = ce.getAttribute("label");
-						String ws = ce.getAttribute("ws");
-						if ((os != null && !os.equals(currentOS)) || (ws != null && !ws.equals(currentWS))) {
-							if (!themesToVarients.containsKey(themeBaseId)) {
-								themesToVarients.put(themeBaseId, new ArrayList<>());
-							}
-							themeId = getVarientThemeId(themeBaseId, os, ws);
-							themesToVarients.get(themeBaseId).add(themeId);
-							label = getVarientThemeLabel(label, os, ws);
-						}
 						String originalCSSFile;
 						String basestylesheeturi = originalCSSFile = ce.getAttribute("basestylesheeturi");
 						if (!basestylesheeturi.startsWith("platform:/plugin/")) {
@@ -179,7 +181,7 @@ public class ThemeEngine implements IThemeEngine {
 		}
 
 		for (IExtension e : extPoint.getExtensions()) {
-			for (IConfigurationElement ce : e.getConfigurationElements()) {
+			for (IConfigurationElement ce : getPlatformMatches(e.getConfigurationElements())) {
 				if (ce.getName().equals("stylesheet")) {
 					IConfigurationElement[] cces = ce.getChildren("themeid");
 					if (cces.length == 0) {
@@ -196,18 +198,14 @@ public class ThemeEngine implements IThemeEngine {
 							}
 						}
 					} else {
-						List<String> themes = new ArrayList<>();
-						for (IConfigurationElement cce : cces) {
-							String refid = cce.getAttribute("refid");
-							List<String> varientOSList = themesToVarients.get(refid);
-							if (varientOSList != null) {
-								themes.addAll(varientOSList);
-							}
-							themes.add(refid);
+						String[] themes = new String[cces.length];
+						for (int i = 0; i < cces.length; i++) {
+							themes[i] = cces[i].getAttribute("refid");
 						}
 						registerStylesheet(
 								"platform:/plugin/" + ce.getContributor().getName() + "/" + ce.getAttribute("uri"),
-								themes.toArray(new String[themes.size()]));
+								themes);
+
 						for (IConfigurationElement resourceEl : ce
 								.getChildren("osgiresourcelocator")) {
 							String uri = resourceEl.getAttribute("uri");
@@ -230,44 +228,6 @@ public class ThemeEngine implements IThemeEngine {
 		// registerResourceLocator(new HttpResourcesLocatorImpl());
 	}
 
-	private String getVarientThemeId(String id, String os, String ws) {
-		if (os != null) {
-			id += '_' + os;
-		}
-		if (ws != null) {
-			id += '-' + ws;
-		}
-		return id;
-	}
-
-	private String getVarientThemeLabel(String label, String os, String ws) {
-		String currentOS = Platform.getOS();
-		String currentWS = Platform.getWS();
-		if (os != null && !os.equals(currentOS)) {
-			String osName;
-			switch (os) {
-			case Platform.OS_LINUX:		osName="Linux";break;
-			case Platform.OS_MACOSX:	osName="Mac OS X";break;
-			case Platform.OS_WIN32:		osName="Windows";break;
-			default:					osName=os;break;
-			}
-			label += " [" + osName;
-		}
-		if (ws != null && !ws.equals(currentWS)) {
-			String wsName;
-			switch (ws) {
-			case Platform.WS_COCOA:		wsName="Cocoa";break;
-			case Platform.WS_GTK:		wsName="GTK";break;
-			case Platform.WS_WPF:		wsName="WPF";break;
-			default:					wsName=ws;break;
-			}
-			label += " - " + wsName;
-		}
-		if (os != null && !os.equals(currentOS)) {
-			label += "]";
-		}
-		return label;
-	}
 
 	private boolean isOsVersionMatch(String osVersionList) {
 		boolean found = false;
@@ -307,7 +267,7 @@ public class ThemeEngine implements IThemeEngine {
 			theme.setOsVersion(osVersion);
 		}
 		themes.add(theme);
-		registerStyle(id, basestylesheetURI);
+		registerStyle(id, basestylesheetURI, false);
 		return theme;
 	}
 
@@ -323,7 +283,7 @@ public class ThemeEngine implements IThemeEngine {
 			globalStyles.add(uri);
 		} else {
 			for (String t : themes) {
-				registerStyle(t, uri);
+				registerStyle(t, uri, true);
 			}
 		}
 	}
@@ -345,16 +305,33 @@ public class ThemeEngine implements IThemeEngine {
 		}
 	}
 
-	private void registerStyle(String id, String stylesheet) {
+	private void registerStyle(String id, String stylesheet, boolean isStyleSheetPluginExtension) {
 		List<String> s = stylesheets.get(id);
 		if (s == null) {
 			s = new ArrayList<>();
 			stylesheets.put(id, s);
 		}
 		s.add(stylesheet);
+		if (isStyleSheetPluginExtension) {
+			s = stylesheetPluginExtensions.get(id);
+			if (s == null) {
+				s = new ArrayList<>();
+				stylesheetPluginExtensions.put(id, s);
+			}
+			s.add(stylesheet);
+		}
 	}
 
-	private List<String> getAllStyles(String id) {
+	private List<String> getAllStyles(ITheme theme) {
+		String id = theme.getId();
+		String idWithoutVersion = null;
+		if (theme instanceof Theme) {
+			Theme th = (Theme) theme;
+			String osVersion = th.getOsVersion();
+			if (osVersion != null && osVersion.length() > 0 && id.endsWith(osVersion)) {
+				idWithoutVersion = id.substring(0, id.length() - osVersion.length());
+			}
+		}
 		// check for any modifications first
 		List<String> m = modifiedStylesheets.get(id);
 		if (m != null) {
@@ -362,16 +339,26 @@ public class ThemeEngine implements IThemeEngine {
 			m.addAll(globalStyles);
 			return m;
 		}
-
 		List<String> s = stylesheets.get(id);
 		if (s == null) {
 			s = Collections.emptyList();
 		}
+		if (idWithoutVersion != null) { // stylesheetPluginExtensions don't have a os_version; ensure that they will
+			// always taken; independent from current os_version
+			List<String> stylesheetPluginExtensionList = stylesheetPluginExtensions.get(idWithoutVersion);
+			if (stylesheetPluginExtensionList != null && stylesheetPluginExtensionList.size() > 0) {
+				s = new ArrayList<>(s);
+				for (String styleSheet : stylesheetPluginExtensionList) {
+					if (s.contains(styleSheet) == false) {
+						s.add(styleSheet);
+					}
+				}
 
+			}
+		}
 		s = new ArrayList<>(s);
 		s.addAll(globalStyles);
 		return s;
-
 	}
 
 	private List<IResourceLocator> getResourceLocators(String id) {
@@ -385,6 +372,31 @@ public class ThemeEngine implements IThemeEngine {
 		return list;
 	}
 
+	/**
+	 * Get all elements that have os/ws attributes that best match the current
+	 * platform.
+	 *
+	 * @param elements the elements to check
+	 * @return the best matches, if any
+	 */
+	private IConfigurationElement[] getPlatformMatches(IConfigurationElement[] elements) {
+		Bundle bundle = FrameworkUtil.getBundle(ThemeEngine.class);
+		String osname = bundle.getBundleContext().getProperty("osgi.os");
+		// TODO: Need to differentiate win32 versions
+		String wsname = bundle.getBundleContext().getProperty("osgi.ws");
+		ArrayList<IConfigurationElement> matchingElements = new ArrayList<>();
+		for (IConfigurationElement element : elements) {
+			String elementOs = element.getAttribute("os");
+			String elementWs = element.getAttribute("ws");
+			if (osname != null && (elementOs == null || elementOs.contains(osname))) {
+				matchingElements.add(element);
+			} else if (wsname != null && wsname.equalsIgnoreCase(elementWs)) {
+				matchingElements.add(element);
+			}
+		}
+		return matchingElements.toArray(new IConfigurationElement[matchingElements.size()]);
+	}
+
 	@Override
 	public void setTheme(String themeId, boolean restore) {
 		String osVersion = System.getProperty("os.version");
@@ -449,11 +461,11 @@ public class ThemeEngine implements IThemeEngine {
 					.registerResourceLocator(l);
 				}
 			}
-			for (String stylesheet : getAllStyles(theme.getId())) {
+			for (String stylesheet : getAllStyles(theme)) {
 				URL url;
 				InputStream stream = null;
 				try {
-					url = FileLocator.resolve(new URL(stylesheet.toString()));
+					url = FileLocator.resolve(new URL(stylesheet));
 					for (CSSEngine engine : cssEngines) {
 						try {
 							stream = url.openStream();
@@ -538,7 +550,7 @@ public class ThemeEngine implements IThemeEngine {
 	@Override
 	public void applyStyles(Object widget, boolean applyStylesToChildNodes) {
 		for (CSSEngine engine : cssEngines) {
-			Object element = engine.getElement(widget);
+			Element element = engine.getElement(widget);
 			if (element != null) {
 				engine.applyStyles(element, applyStylesToChildNodes);
 			}
@@ -578,6 +590,16 @@ public class ThemeEngine implements IThemeEngine {
 	@Override
 	public void restore(String alternateTheme) {
 		String prefThemeId = getPreferenceThemeId();
+
+		// Bug 562794, 563601: Eclipse once contained two identical themes named
+		// "Classic" and "Windows Classic" and the second was removed with bug 562794.
+		// An old workspace using the removed "Windows Classic" theme would be reseted
+		// to the default theme on update. Since both themes are identical we silently
+		// change the theme to the remaining "Classic" theme and don't disturb the user.
+		if ("org.eclipse.e4.ui.css.theme.e4_classic6.0,6.1,6.2,6.3".equals(prefThemeId)) { //$NON-NLS-1$
+			prefThemeId = "org.eclipse.e4.ui.css.theme.e4_classic"; //$NON-NLS-1$
+		}
+
 		boolean flag = true;
 		if (prefThemeId != null) {
 			for (ITheme t : getThemes()) {
@@ -589,8 +611,17 @@ public class ThemeEngine implements IThemeEngine {
 			}
 		}
 
-		if (alternateTheme != null && flag) {
-			setTheme(alternateTheme, false);
+		/*
+		 * Any Platform: if the system has Dark appearance set and Eclipse is using the
+		 * default settings, then start Eclipse in Dark theme. Check that there is a
+		 * dark theme present. Can be disabled using a system property.
+		 */
+		boolean hasDarkTheme = getThemes().stream().anyMatch(t -> t.getId().startsWith(E4_DARK_THEME_ID));
+		boolean disableOSDarkThemeInherit = "true".equalsIgnoreCase(System.getProperty(DISABLE_OS_DARK_THEME_INHERIT));
+		boolean overrideWithDarkTheme = Display.isSystemDarkTheme() && hasDarkTheme && !disableOSDarkThemeInherit;
+		String themeToRestore = overrideWithDarkTheme ? E4_DARK_THEME_ID : alternateTheme;
+		if (themeToRestore != null && flag) {
+			setTheme(themeToRestore, false);
 		}
 	}
 
