@@ -21,12 +21,12 @@ import org.eclipse.swt.widgets.ToolItem;
  */
 public class ToolItemEnabledProperty extends WidgetBooleanValueProperty<ToolItem> {
 	@Override
-	public boolean doGetBooleanValue(ToolItem source) {
+	protected boolean doGetBooleanValue(ToolItem source) {
 		return source.getEnabled();
 	}
 
 	@Override
-	void doSetBooleanValue(ToolItem source, boolean value) {
+	protected void doSetBooleanValue(ToolItem source, boolean value) {
 		source.setEnabled(value);
 	}
 
