@@ -25,6 +25,7 @@ import java.util.ArrayList;
 
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.MultiStatus;
 import org.eclipse.jface.resource.JFaceResources;
 import org.eclipse.jface.util.Policy;
 import org.eclipse.swt.SWT;
@@ -134,8 +135,7 @@ public class ErrorDialog extends IconAndMessageDialog {
 	 *                    as per <code>IStatus.matches</code>
 	 * @see org.eclipse.core.runtime.IStatus#matches(int)
 	 */
-	public ErrorDialog(Shell parentShell, String dialogTitle, String message,
-			IStatus status, int displayMask) {
+	public ErrorDialog(Shell parentShell, String dialogTitle, String message, IStatus status, int displayMask) {
 		super(parentShell);
 		this.title = dialogTitle == null ? JFaceResources
 				.getString("Problem_Occurred") : //$NON-NLS-1$
@@ -172,8 +172,7 @@ public class ErrorDialog extends IconAndMessageDialog {
 	@Override
 	protected void createButtonsForButtonBar(Composite parent) {
 		// create OK and Details buttons
-		createButton(parent, IDialogConstants.OK_ID, IDialogConstants.OK_LABEL,
-				true);
+		createButton(parent, IDialogConstants.OK_ID, IDialogConstants.OK_LABEL, true);
 		createDetailsButton(parent);
 	}
 
@@ -338,6 +337,14 @@ public class ErrorDialog extends IconAndMessageDialog {
 	 */
 	@Override
 	public int open() {
+		if (AUTOMATED_MODE) {
+			IllegalStateException e = new IllegalStateException("Error dialog is supposed to be shown now"); //$NON-NLS-1$
+			MultiStatus ms = new MultiStatus("org.eclipse.jface", IStatus.ERROR, title + " : " + message, e); //$NON-NLS-1$ //$NON-NLS-2$
+			if (status != null) {
+				ms.add(status);
+			}
+			Policy.getLog().log(ms);
+		}
 		if (!AUTOMATED_MODE && shouldDisplay(status, displayMask)) {
 			return super.open();
 		}
@@ -366,10 +373,9 @@ public class ErrorDialog extends IconAndMessageDialog {
 	 *         button was pressed, or <code>Dialog.CANCEL</code> if this
 	 *         dialog's close window decoration or the ESC key was used.
 	 */
-	public static int openError(Shell parent, String dialogTitle,
-			String message, IStatus status) {
-		return openError(parent, dialogTitle, message, status, IStatus.OK
-				| IStatus.INFO | IStatus.WARNING | IStatus.ERROR);
+	public static int openError(Shell parent, String dialogTitle, String message, IStatus status) {
+		return openError(parent, dialogTitle, message, status,
+				IStatus.OK | IStatus.INFO | IStatus.WARNING | IStatus.ERROR);
 	}
 
 	/**
@@ -395,10 +401,8 @@ public class ErrorDialog extends IconAndMessageDialog {
 	 *         decoration or the ESC key was used.
 	 * @see org.eclipse.core.runtime.IStatus#matches(int)
 	 */
-	public static int openError(Shell parentShell, String title,
-			String message, IStatus status, int displayMask) {
-		ErrorDialog dialog = new ErrorDialog(parentShell, title, message,
-				status, displayMask);
+	public static int openError(Shell parentShell, String title, String message, IStatus status, int displayMask) {
+		ErrorDialog dialog = new ErrorDialog(parentShell, title, message, status, displayMask);
 		return dialog.open();
 	}
 
@@ -414,8 +418,7 @@ public class ErrorDialog extends IconAndMessageDialog {
 	 * @see #listContentExists()
 	 */
 	private void populateList(List listToPopulate) {
-		populateList(listToPopulate, status, 0,
-				shouldIncludeTopLevelErrorInDetails);
+		populateList(listToPopulate, status, 0, shouldIncludeTopLevelErrorInDetails);
 	}
 
 	/**
@@ -496,7 +499,7 @@ public class ErrorDialog extends IconAndMessageDialog {
 			IStatus eStatus = ce.getStatus();
 			// Only print the exception message if it is not contained in the
 			// parent message
-			if (message == null || message.indexOf(eStatus.getMessage()) == -1) {
+			if (message == null || !message.contains(eStatus.getMessage())) {
 				populateList(listToPopulate, eStatus, nesting, true);
 			}
 		}
@@ -559,7 +562,7 @@ public class ErrorDialog extends IconAndMessageDialog {
 			IStatus eStatus = ce.getStatus();
 			// Gets exception message if it is not contained in the
 			// parent message
-			if (message == null || message.indexOf(eStatus.getMessage()) == -1) {
+			if (message == null || !message.contains(eStatus.getMessage())) {
 				result |= listContentExists(eStatus, true);
 			}
 		}
@@ -750,8 +753,11 @@ public class ErrorDialog extends IconAndMessageDialog {
 		}
 	}
 
+	/**
+	 * @since 3.22
+	 */
 	@Override
-	int getColumnCount() {
+	protected int getColumnCount() {
 		if (Policy.getErrorSupportProvider() == null)
 			return 2;
 		return 3;
