@@ -23,8 +23,10 @@ import org.eclipse.jface.resource.JFaceResources;
 import org.eclipse.jface.window.ToolTip;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.accessibility.ACC;
+import org.eclipse.swt.accessibility.AccessibleAdapter;
 import org.eclipse.swt.accessibility.AccessibleAttributeAdapter;
 import org.eclipse.swt.accessibility.AccessibleAttributeEvent;
+import org.eclipse.swt.accessibility.AccessibleEvent;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.Point;
@@ -112,6 +114,8 @@ public class TitleAreaDialog extends TrayDialog {
 
 	private Image messageImage;
 
+	private String messageImageTooltip;
+
 	private boolean showingError = false;
 
 	private boolean titleImageLargest = true;
@@ -260,6 +264,15 @@ public class TitleAreaDialog extends TrayDialog {
 		// Message image @ bottom, left
 		messageImageLabel = new Label(parent, SWT.CENTER);
 		messageImageLabel.setBackground(background);
+		messageImageLabel.getAccessible().addAccessibleListener(new AccessibleAdapter() {
+			@Override
+			public void getName(AccessibleEvent event) {
+				if (messageImageTooltip == null) {
+					return;
+				}
+				event.result = messageImageTooltip;
+			}
+		});
 		// Message label @ bottom, center
 		messageLabel = new Text(parent, SWT.WRAP | SWT.READ_ONLY);
 		JFaceColors.setColors(messageLabel, foreground, background);
@@ -410,6 +423,7 @@ public class TitleAreaDialog extends TrayDialog {
 				message = ""; //$NON-NLS-1$
 			updateMessage(message);
 			messageImageLabel.setImage(messageImage);
+			messageImageLabel.setToolTipText(messageImageTooltip);
 			setImageLabelVisible(messageImage != null);
 		} else {
 			// Add in a space for layout purposes but do not
@@ -563,22 +577,26 @@ public class TitleAreaDialog extends TrayDialog {
 	 */
 	public void setMessage(String newMessage, int newType) {
 		Image newImage = null;
+		String newImageTooltip = null;
 		if (newMessage != null) {
 			switch (newType) {
 			case IMessageProvider.NONE:
 				break;
 			case IMessageProvider.INFORMATION:
 				newImage = JFaceResources.getImage(DLG_IMG_MESSAGE_INFO);
+				newImageTooltip = JFaceResources.getString("info"); //$NON-NLS-1$
 				break;
 			case IMessageProvider.WARNING:
 				newImage = JFaceResources.getImage(DLG_IMG_MESSAGE_WARNING);
+				newImageTooltip = JFaceResources.getString("warning"); //$NON-NLS-1$
 				break;
 			case IMessageProvider.ERROR:
 				newImage = JFaceResources.getImage(DLG_IMG_MESSAGE_ERROR);
+				newImageTooltip = JFaceResources.getString("error"); //$NON-NLS-1$
 				break;
 			}
 		}
-		showMessage(newMessage, newImage);
+		showMessage(newMessage, newImage, newImageTooltip);
 	}
 
 	/**
@@ -587,7 +605,7 @@ public class TitleAreaDialog extends TrayDialog {
 	 * @param newMessage
 	 * @param newImage
 	 */
-	private void showMessage(String newMessage, Image newImage) {
+	private void showMessage(String newMessage, Image newImage, String newImageTooltip) {
 		// https://bugs.eclipse.org/bugs/show_bug.cgi?id=249915
 		if (newMessage == null)
 			newMessage = ""; //$NON-NLS-1$
@@ -602,10 +620,12 @@ public class TitleAreaDialog extends TrayDialog {
 		// a space to the message for layout purposes
 		String shownMessage = (newImage == null) ? message : " " + message; //$NON-NLS-1$
 		messageImage = newImage;
+		messageImageTooltip = newImageTooltip;
 		if (!showingError) {
 			// we are not showing an error
 			updateMessage(shownMessage);
 			messageImageLabel.setImage(messageImage);
+			messageImageLabel.setToolTipText(messageImageTooltip);
 			setImageLabelVisible(messageImage != null);
 			layoutForNewMessage(false);
 		}
