@@ -69,7 +69,7 @@ public class ViewerComparator {
 	 * comparator to be able to compare the {@link String}s provided by the
 	 * viewer's label provider.
 	 *
-	 * @param comparator
+	 * @param comparator the comparator to use
 	 */
 	public ViewerComparator(Comparator<? super String> comparator) {
 		this.comparator = comparator;
@@ -205,7 +205,7 @@ public class ViewerComparator {
 		try {
 			Arrays.sort(elements, (a, b) -> ViewerComparator.this.compare(viewer, a, b));
 		} catch (IllegalArgumentException e) {
-			String msg = e.toString()
+			String msg = e
 					+ "\nWorkaround for comparator violation:\n\tSet system property -Djava.util.Arrays.useLegacyMergeSort=true" //$NON-NLS-1$
 					+ "\nthis: " + getClass().getName() //$NON-NLS-1$
 					+ "\ncomparator: " + (comparator != null ? comparator.getClass().getName() : null) //$NON-NLS-1$
