@@ -359,9 +359,9 @@ public abstract class Window implements IShellProvider {
 		// disposed images from the array passed to the shell.
 		if (defaultImages != null && defaultImages.length > 0) {
 			ArrayList<Image> nonDisposedImages = new ArrayList<>(defaultImages.length);
-			for (int i = 0; i < defaultImages.length; ++i) {
-				if (defaultImages[i] != null && !defaultImages[i].isDisposed()) {
-					nonDisposedImages.add(defaultImages[i]);
+			for (Image defaultImage : defaultImages) {
+				if (defaultImage != null && !defaultImage.isDisposed()) {
+					nonDisposedImages.add(defaultImage);
 				}
 			}
 
@@ -984,12 +984,11 @@ public abstract class Window implements IShellProvider {
 	/**
 	 * Sets the exception handler for this application.
 	 * <p>
-	 * Note that the handler may only be set once.  Subsequent calls to this method will be
-	 * ignored.
-	 * <p>
+	 * Note that the handler may only be set once. Subsequent calls to this method
+	 * will be ignored.
+	 * </p>
 	 *
-	 * @param handler
-	 *            the exception handler for the application.
+	 * @param handler the exception handler for the application.
 	 */
 	public static void setExceptionHandler(IExceptionHandler handler) {
 		if (exceptionHandler instanceof DefaultExceptionHandler) {
