@@ -19,6 +19,7 @@ import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.io.File;
 import java.io.IOException;
+import java.net.URI;
 import java.nio.file.ClosedWatchServiceException;
 import java.nio.file.FileSystems;
 import java.nio.file.Path;
@@ -29,6 +30,7 @@ import java.nio.file.WatchService;
 import java.util.ArrayList;
 import java.util.List;
 
+import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.jface.action.IStatusLineManager;
 import org.eclipse.jface.resource.ImageDescriptor;
@@ -44,6 +46,7 @@ import org.eclipse.swt.browser.ProgressListener;
 import org.eclipse.swt.browser.VisibilityWindowAdapter;
 import org.eclipse.swt.browser.WindowEvent;
 import org.eclipse.swt.dnd.Clipboard;
+import org.eclipse.swt.events.DisposeEvent;
 import org.eclipse.swt.events.MouseAdapter;
 import org.eclipse.swt.events.MouseEvent;
 import org.eclipse.swt.events.SelectionListener;
@@ -60,11 +63,12 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.ToolBar;
 import org.eclipse.swt.widgets.ToolItem;
 import org.eclipse.ui.PlatformUI;
+import org.eclipse.urischeme.IUriSchemeProcessor;
 
 /**
  * A Web browser widget. It extends the Eclipse SWT Browser widget by adding an
- * optional toolbar complete with a URL combo box, history, back & forward, and
- * refresh buttons.
+ * optional toolbar complete with a URL combo box, history, back &amp; forward,
+ * and refresh buttons.
  * <p>
  * Use the style bits to choose which toolbars are available within the browser
  * composite. You can access the embedded SWT Browser directly using the
@@ -215,7 +219,7 @@ public class BrowserViewer extends Composite {
 			if (showURLbar)
 				createLocationBar(toolbarComp);
 
-			if (showToolbar | showURLbar) {
+			if (showToolbar || showURLbar) {
 				busy = new BusyIndicator(toolbarComp, SWT.NONE);
 				busy.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_END));
 				busy.addMouseListener(new MouseAdapter() {
@@ -233,6 +237,20 @@ public class BrowserViewer extends Composite {
 		//if (WebBrowserUtil.canUseInternalWebBrowser())
 		try {
 			this.browser = new Browser(this, SWT.NONE);
+			this.browser.addLocationListener(LocationListener.changingAdapter(event -> {
+					URI uri = URI.create(event.location);
+					if (!(uri.getScheme().equals("http") || uri.getScheme().equals("https") //$NON-NLS-1$ //$NON-NLS-2$
+							|| uri.getScheme().equals("file"))) //$NON-NLS-1$
+						try {
+							if (IUriSchemeProcessor.INSTANCE.canHandle(uri)) {
+								IUriSchemeProcessor.INSTANCE.handleUri(uri);
+								event.doit = false;
+							}
+						} catch (CoreException e) {
+							WebBrowserUIPlugin.logError(e.getMessage(), e);
+						}
+
+				}));
 		}
 		catch (SWTError e) {
 			if (e.code!=SWT.ERROR_NO_HANDLES) {
@@ -256,7 +274,7 @@ public class BrowserViewer extends Composite {
 			text.getControl().setLayoutData(new GridData(GridData.FILL_BOTH));
 
 		addBrowserListeners();
-		//listen();
+		addDisposeListener(this::dispose);
 	}
 
 	/**
@@ -688,8 +706,9 @@ public class BrowserViewer extends Composite {
 		else if ("wtp".equalsIgnoreCase(url)) //$NON-NLS-1$
 			url = "http://www.eclipse.org/webtools/"; //$NON-NLS-1$
 
-		if (browse)
+		if (browse) {
 			navigate(url);
+		}
 
 		addToHistory(url);
 		updateHistory();
@@ -723,10 +742,7 @@ public class BrowserViewer extends Composite {
 	/**
 	 *
 	 */
-	@Override
-	public void dispose() {
-		super.dispose();
-
+	private void dispose(DisposeEvent event) {
 		showToolbar = false;
 
 		if (busy != null)
@@ -739,6 +755,15 @@ public class BrowserViewer extends Composite {
 			clipboard.dispose();
 		clipboard=null;
 
+		if (watcher != null) {
+			try {
+				watcher.close();
+			} catch (IOException e) {
+				WebBrowserUIPlugin.logError(e.getMessage(), e);
+			}
+		}
+		watcher = null;
+
 		removeSynchronizationListener();
 	}
 
@@ -974,7 +999,7 @@ public class BrowserViewer extends Composite {
 			}
 			watcher = FileSystems.getDefault().newWatchService();
 			final Path path = FileSystems.getDefault().getPath(file.getAbsolutePath());
-			path.register(watcher, StandardWatchEventKinds.ENTRY_MODIFY);
+			path.register(watcher, StandardWatchEventKinds.ENTRY_CREATE, StandardWatchEventKinds.ENTRY_MODIFY);
 			new Thread(() -> {
 				try {
 					WatchKey key = watcher.take();
