@@ -29,6 +29,7 @@ import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.jface.dialogs.Dialog;
 import org.eclipse.jface.dialogs.ProgressMonitorDialog;
 import org.eclipse.jface.operation.IRunnableWithProgress;
+import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.preference.PreferencePage;
 import org.eclipse.jface.viewers.CheckboxTableViewer;
 import org.eclipse.jface.viewers.ColumnWeightData;
@@ -541,10 +542,7 @@ public class WebBrowserPreferencePage extends PreferencePage implements
 	 */
 	@Override
 	protected void performDefaults() {
-		internal.setSelection(WebBrowserPreference
-				.isDefaultUseInternalBrowser());
-		external.setSelection(!WebBrowserPreference.
-				isDefaultUseInternalBrowser());
+		setDefaultChoiceSelection();
 
 		BrowserManager.getInstance().currentBrowser = null;
 		BrowserManager.getInstance().setupDefaultBrowsers();
@@ -563,10 +561,7 @@ public class WebBrowserPreferencePage extends PreferencePage implements
 	 * appeared after the Eclipse Platform update.
 	 */
 	protected void addDefaults() {
-		internal.setSelection(WebBrowserPreference
-				.isDefaultUseInternalBrowser());
-		external.setSelection(!WebBrowserPreference.
-				isDefaultUseInternalBrowser());
+		setDefaultChoiceSelection();
 
 		BrowserManager.getInstance().currentBrowser = null;
 		BrowserManager.getInstance().addDefaultBrowsers();
@@ -604,4 +599,17 @@ public class WebBrowserPreferencePage extends PreferencePage implements
 		BrowserManager.getInstance().loadBrowsers();
 		return super.performCancel();
 	}
+
+	private void setDefaultChoiceSelection() {
+		int browserChoice = getBrowserChoiceDefaultPreference();
+		internal.setSelection(browserChoice == WebBrowserPreference.INTERNAL);
+		external.setSelection(browserChoice == WebBrowserPreference.EXTERNAL);
+	}
+
+	private static int getBrowserChoiceDefaultPreference() {
+		IPreferenceStore preferenceStore = WebBrowserUIPlugin.getInstance().getPreferenceStore();
+		int browserChoice = preferenceStore.getDefaultInt(WebBrowserPreference.PREF_BROWSER_CHOICE);
+		return browserChoice;
+
+	}
 }
