@@ -548,8 +548,7 @@ public final class TableWrapLayout extends Layout implements ILayoutExtension {
 	private void updateGrowingColumns(ArrayList<Integer> growingColumns,
 			TableWrapData spec, int column) {
 		int affectedColumn = column + spec.colspan - 1;
-		for (int i = 0; i < growingColumns.size(); i++) {
-			Integer col = growingColumns.get(i);
+		for (Integer col : growingColumns) {
 			if (col.intValue() == affectedColumn)
 				return;
 		}
@@ -559,8 +558,7 @@ public final class TableWrapLayout extends Layout implements ILayoutExtension {
 	private void updateGrowingRows(ArrayList<Integer> growingRows, TableWrapData spec,
 			int row) {
 		int affectedRow = row + spec.rowspan - 1;
-		for (int i = 0; i < growingRows.size(); i++) {
-			Integer irow = growingRows.get(i);
+		for (Integer irow : growingRows) {
 			if (irow.intValue() == affectedRow)
 				return;
 		}
@@ -645,7 +643,6 @@ public final class TableWrapLayout extends Layout implements ILayoutExtension {
 				columnWidths = assignExtraSpace(tableWidth, maxWidth, minWidth);
 			}
 		}
-		int totalHeight = 0;
 		int innerHeight = 0;
 		// compute widths
 		for (int i = 0; i < grid.size(); i++) {
@@ -688,7 +685,7 @@ public final class TableWrapLayout extends Layout implements ILayoutExtension {
 		}
 		if (!rowspans.isEmpty())
 			innerHeight = compensateForRowSpans(innerHeight);
-		totalHeight = topMargin + innerHeight + bottomMargin;
+		int totalHeight = topMargin + innerHeight + bottomMargin;
 		return new Point(tableWidth, totalHeight);
 	}
 
@@ -765,8 +762,7 @@ public final class TableWrapLayout extends Layout implements ILayoutExtension {
 	void calculateColumnWidths(Composite parent, int [] columnWidths, boolean max, boolean changed, boolean makeColumnsEqualWidth2) {
 		boolean secondPassNeeded=false;
 		int widestColumnWidth = 0;
-		for (int i = 0; i < grid.size(); i++) {
-			TableWrapData[] row = grid.get(i);
+		for (TableWrapData[] row : grid) {
 			for (int j = 0; j < numColumns; j++) {
 				TableWrapData td = row[j];
 				if (td.isItemData == false)
@@ -799,8 +795,7 @@ public final class TableWrapLayout extends Layout implements ILayoutExtension {
 		if (!secondPassNeeded) return;
 
 		// Second pass for controls with multi-column horizontal span
-		for (int i = 0; i < grid.size(); i++) {
-			TableWrapData[] row = grid.get(i);
+		for (TableWrapData[] row : grid) {
 			for (int j = 0; j < numColumns; j++) {
 				TableWrapData td = row[j];
 				if (td.isItemData == false || td.colspan==1)
