@@ -113,7 +113,7 @@ public class FormHeading extends Canvas {
 			if (messageRegion != null)
 				messageRegion.updateToolTip(details);
 			if (getMessageType() > 0
-					&& (details == null || details.length() == 0))
+					&& (details == null || details.isEmpty()))
 				details = getMessage();
 			titleRegion.updateToolTip(details);
 		}
@@ -612,7 +612,7 @@ public class FormHeading extends Canvas {
 			if (gradientInfo != null || (backgroundImage != null && !isBackgroundImageTiled()))
 				updateGradientImage();
 		});
-		addMouseMoveListener(e -> updateTitleRegionHoverState(e));
+		addMouseMoveListener(this::updateTitleRegionHoverState);
 		addMouseTrackListener(new MouseTrackListener() {
 			@Override
 			public void mouseEnter(MouseEvent e) {
