@@ -14,6 +14,7 @@
  *******************************************************************************/
 package org.eclipse.ui.internal.forms.widgets;
 
+import java.text.BreakIterator;
 import java.util.ArrayList;
 import java.util.Hashtable;
 import java.util.Vector;
@@ -27,11 +28,8 @@ import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
 
-import com.ibm.icu.text.BreakIterator;
-
 /**
  * @version 1.0
- * @author
  */
 public class TextSegment extends ParagraphSegment {
 	private String colorId;
@@ -349,8 +347,7 @@ public class TextSegment extends ParagraphSegment {
 			Rectangle repaintRegion) {
 		if (areaRectangles == null)
 			return;
-		for (int i = 0; i < areaRectangles.size(); i++) {
-			AreaRectangle areaRectangle = areaRectangles.get(i);
+		for (AreaRectangle areaRectangle : areaRectangles) {
 			Rectangle br = areaRectangle.rect;
 			int bx = br.x;
 			int by = br.y;
@@ -381,8 +378,6 @@ public class TextSegment extends ParagraphSegment {
 			Rectangle repaintRegion) {
 		Font oldFont = null;
 		Color oldColor = null;
-		Color oldBg = null;
-
 		// apply segment-specific font, color and background
 		if (fontId != null) {
 			oldFont = gc.getFont();
@@ -396,15 +391,14 @@ public class TextSegment extends ParagraphSegment {
 			if (newColor != null)
 				gc.setForeground(newColor);
 		}
-		oldBg = gc.getBackground();
+		Color oldBg = gc.getBackground();
 
 		FontMetrics fm = gc.getFontMetrics();
 		int lineHeight = fm.getHeight();
 		int descent = fm.getDescent();
 
 		// paint area rectangles of the segment
-		for (int i = 0; i < areaRectangles.size(); i++) {
-			AreaRectangle areaRectangle = areaRectangles.get(i);
+		for (AreaRectangle areaRectangle : areaRectangles) {
 			Rectangle rect = areaRectangle.rect;
 			String text = areaRectangle.getText();
 			Point extent = gc.textExtent(text);
@@ -451,8 +445,7 @@ public class TextSegment extends ParagraphSegment {
 				gc.setFont(newFont);
 		}
 
-		for (int i = 0; i < areaRectangles.size(); i++) {
-			AreaRectangle areaRectangle = areaRectangles.get(i);
+		for (AreaRectangle areaRectangle : areaRectangles) {
 			Rectangle rect = areaRectangle.rect;
 			String text = areaRectangle.getText();
 			Point extent = gc.textExtent(text);
