@@ -323,7 +323,7 @@ public class IDEWorkbenchAdvisor extends WorkbenchAdvisor {
 
 				// make sure they really want to do this
 				if (new MessageDialog(null, IDEWorkbenchMessages.SystemSettingsChange_title, null,
-						IDEWorkbenchMessages.SystemSettingsChange_message, MessageDialog.QUESTION, 1,
+						IDEWorkbenchMessages.SystemSettingsChange_message, MessageDialog.NONE, 1,
 						IDEWorkbenchMessages.SystemSettingsChange_yes, IDEWorkbenchMessages.SystemSettingsChange_no)
 								.open() == Window.OK) {
 					PlatformUI.getWorkbench().restart();
@@ -569,10 +569,10 @@ public class IDEWorkbenchAdvisor extends WorkbenchAdvisor {
 					IDEWorkbenchPlugin.IDE_WORKBENCH, 1,
 					IDEWorkbenchMessages.InternalError, e));
 		}
-		ErrorDialog.openError(null,
-				IDEWorkbenchMessages.ProblemsSavingWorkspace, null, status,
-				IStatus.ERROR | IStatus.WARNING);
 		if (!status.isOK()) {
+			ErrorDialog.openError(null,
+					IDEWorkbenchMessages.ProblemsSavingWorkspace, null, status,
+					IStatus.ERROR | IStatus.WARNING);
 			IDEWorkbenchPlugin.log(
 					IDEWorkbenchMessages.ProblemsSavingWorkspace, status);
 		}
