@@ -21,15 +21,14 @@ package org.eclipse.ui.dialogs;
 import java.io.IOException;
 import java.io.StringReader;
 import java.io.StringWriter;
+import java.text.CollationKey;
 import java.text.Collator;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Comparator;
+import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
 
 import org.eclipse.core.resources.IContainer;
 import org.eclipse.core.resources.IResource;
@@ -82,11 +81,11 @@ import org.eclipse.ui.ide.ResourceUtil;
 import org.eclipse.ui.internal.WorkbenchMessages;
 import org.eclipse.ui.internal.WorkbenchPlugin;
 import org.eclipse.ui.internal.ide.IDEWorkbenchMessages;
-import org.eclipse.ui.internal.ide.IDEWorkbenchPlugin;
 import org.eclipse.ui.internal.ide.IIDEHelpContextIds;
 import org.eclipse.ui.internal.ide.model.ResourceFactory;
 import org.eclipse.ui.model.WorkbenchLabelProvider;
 import org.eclipse.ui.statushandlers.StatusManager;
+import org.osgi.framework.FrameworkUtil;
 
 /**
  * Shows a list of resources to the user with a text entry field for a string
@@ -138,6 +137,22 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 
 	private boolean isDerived;
 
+	/**
+	 * Cache for Collator used by sorting. The allocated memory is reclaimed as soon
+	 * as the Dialog is closed.
+	 */
+	private final Map<String, CollationKey> collationKeyCache = new HashMap<>();
+	private final java.util.Comparator<String> collator = new Comparator<>() {
+		Collator c = Collator.getInstance();
+
+		@Override
+		public int compare(String s1, String s2) {
+			CollationKey ck1 = collationKeyCache.computeIfAbsent(s1, c::getCollationKey);
+			CollationKey ck2 = collationKeyCache.computeIfAbsent(s2, c::getCollationKey);
+			return ck1.compareTo(ck2);
+		}
+	};
+
 	/**
 	 * Creates a new instance of the class
 	 *
@@ -227,10 +242,13 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 
 	@Override
 	protected IDialogSettings getDialogSettings() {
-		IDialogSettings settings = IDEWorkbenchPlugin.getDefault().getDialogSettings().getSection(DIALOG_SETTINGS);
+		IDialogSettings dialogSettings = PlatformUI
+				.getDialogSettingsProvider(FrameworkUtil.getBundle(FilteredResourcesSelectionDialog.class))
+				.getDialogSettings();
+		IDialogSettings settings = dialogSettings.getSection(DIALOG_SETTINGS);
 
 		if (settings == null) {
-			settings = IDEWorkbenchPlugin.getDefault().getDialogSettings().addNewSection(DIALOG_SETTINGS);
+			settings = dialogSettings.addNewSection(DIALOG_SETTINGS);
 		}
 
 		return settings;
@@ -377,6 +395,12 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 		return super.open();
 	}
 
+	@Override
+	public boolean close() {
+		collationKeyCache.clear();
+		return super.close();
+	}
+
 	@Override
 	public String getElementName(Object item) {
 		IResource resource = (IResource) item;
@@ -400,17 +424,14 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 	}
 
 	@Override
-	protected Comparator getItemsComparator() {
+	protected Comparator<IResource> getItemsComparator() {
 		final String pattern;
 		if (latestFilter != null) {
 			pattern = latestFilter.getPattern();
 		} else {
 			pattern = null;
 		}
-		return (o1, o2) -> {
-			Collator collator = Collator.getInstance();
-			IResource resource1 = (IResource) o1;
-			IResource resource2 = (IResource) o2;
+		return (resource1, resource2) -> {
 			String s1 = resource1.getName();
 			String s2 = resource2.getName();
 
@@ -539,6 +560,13 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 		progressMonitor.done();
 	}
 
+	private boolean parentIsRoot(IResource resource) {
+		if (resource.getParent() == null) {
+			return false;
+		}
+		return resource.getParent().getType() == IResource.ROOT;
+	}
+
 	/**
 	 * Sets the derived flag on the ResourceFilter instance
 	 */
@@ -619,10 +647,11 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 			}
 
 			IResource res = (IResource) element;
-
 			StringBuilder str = new StringBuilder(res.getName());
-			str.append(" - "); //$NON-NLS-1$
-			str.append(res.getParent().getFullPath().makeRelative().toString());
+			if (!parentIsRoot(res)) {
+				str.append(" - "); //$NON-NLS-1$
+				str.append(res.getParent().getFullPath().makeRelative().toString());
+			}
 
 			return str.toString();
 		}
@@ -634,7 +663,9 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 			}
 
 			IResource resource = (IResource) element;
-			String searchFieldString = escapeRegexCharacters(((Text) getPatternControl()).getText());
+			String searchFieldString = ((Text) getPatternControl()).getText();
+
+			// We highlight just the matches in resource name, so cut off path if any
 			int fileNameIndex = searchFieldString.lastIndexOf('/');
 			if (fileNameIndex != -1 && fileNameIndex != searchFieldString.length() - 1) {
 				searchFieldString = searchFieldString.substring(fileNameIndex + 1);
@@ -646,31 +677,38 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 					textStyle.font = JFaceResources.getFontRegistry().getBold(JFaceResources.DEFAULT_FONT);
 				}
 			};
+
+			// Firstly style the extension part (if any), then style the rest
 			StyledString str = styleResourceExtensionMatch(resource, searchFieldString, boldStyler);
-			if (str.getStyleRanges().length != 0 && searchFieldString.lastIndexOf('.') != -1) {
-				resourceName = resourceName.substring(0, resourceName.lastIndexOf('.' + resource.getFileExtension()));
+			if (str.getStyleRanges().length > 0) {
+				resourceName = resourceName.substring(0, resourceName.lastIndexOf('.'));
 				searchFieldString = searchFieldString.substring(0, searchFieldString.lastIndexOf('.'));
 			}
 			getMatchPositions(resourceName, searchFieldString).stream()
 					.forEach(position -> str.setStyle(position.offset, position.length, boldStyler));
 
-			// Show extra package info on every element
-			str.append(" - ", StyledString.QUALIFIER_STYLER); //$NON-NLS-1$
-			str.append(resource.getParent().getFullPath().makeRelative().toString(), StyledString.QUALIFIER_STYLER);
-
+			if (!parentIsRoot(resource)) {
+				// Show extra package info on elements not in root
+				str.append(" - ", StyledString.QUALIFIER_STYLER); //$NON-NLS-1$
+				str.append(resource.getParent().getFullPath().makeRelative().toString(), StyledString.QUALIFIER_STYLER);
+			}
 			return str;
 		}
 
 		private StyledString styleResourceExtensionMatch(IResource resource, String matchingString, Styler styler) {
 			StyledString str = new StyledString(resource.getName());
 			String resourceExtension = resource.getFileExtension();
-			int lastDotIndex = matchingString.lastIndexOf('.');
-			if (lastDotIndex == -1 || resourceExtension == null) {
+			if (resourceExtension == null) {
 				return str;
 			}
+			int matchingExtensionIndex = matchingString.lastIndexOf('.');
+			if (matchingExtensionIndex == -1) {
+				return str;
+			}
+
 			resourceExtension = '.' + resourceExtension;
-			int resourceExtensionIndex = resource.getName().lastIndexOf(resourceExtension);
-			String matchingExtension = matchingString.substring(lastDotIndex, matchingString.length());
+			int resourceExtensionIndex = resource.getName().length() - resourceExtension.length();
+			String matchingExtension = matchingString.substring(matchingExtensionIndex, matchingString.length());
 			for (Position markPosition : getMatchPositions(resourceExtension, matchingExtension)) {
 				str.setStyle(resourceExtensionIndex + markPosition.offset, markPosition.length, styler);
 			}
@@ -678,81 +716,53 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 		}
 
 		private List<Position> getMatchPositions(String string, String matching) {
-			final String originalMatching = matching;
 			List<Position> positions = new ArrayList<>();
 			if (matching.isEmpty() || string.isEmpty()) {
 				return positions;
 			}
 
+			// Pre-process the matching pattern
 			char lastChar = matching.charAt(matching.length() - 1);
-			if (lastChar == ' ') {
+			if (lastChar == ' ' || lastChar == '<') {
 				matching = matching.substring(0, matching.length() - 1);
-			} else if (lastChar == '<') {
-				matching = matching.substring(0, matching.length() - 2);
 			}
+
+			String[] regions;
 			if (matching.indexOf('?') == -1 && matching.indexOf('*') == -1) {
-				matching = String.join("*", matching.split("(?=[A-Z0-9])")) + "*"; //$NON-NLS-1$//$NON-NLS-2$ //$NON-NLS-3$
+				// Expect that CamelCase search was possibly performed
+				regions = matching.split("(?=[A-Z0-9])"); //$NON-NLS-1$
 			} else {
-				matching = matching.toLowerCase().replaceAll("\\\\\\\\", "\\\\"); //$NON-NLS-1$ //$NON-NLS-2$
+				regions = matching.toLowerCase().split("[?*]"); //$NON-NLS-1$
 				string = string.toLowerCase();
 			}
 
-			int startingIndex = 0;
+			// Try to match string parts against the pattern regions firstly
 			int currentIndex = 0;
-			String[] regions = matching.replaceAll("\\.", "\\\\.").split("(\\?)|\\*"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
-			int usedRegions = 0;
-			boolean restart = false;
+			boolean regionsDontMatch = false;
+			for (String region : regions) {
+				if (region.isEmpty()) {
+					continue;
+				}
+				int startlocation = string.substring(currentIndex).indexOf(region);
+				if (startlocation == -1) {
+					regionsDontMatch = true;
+					break;
+				}
+				currentIndex += startlocation;
+				positions.add(new Position(currentIndex, region.length()));
+				currentIndex += region.length();
+			}
 
-			do {
-				for (String region : regions) {
-					if (region == null || region.isEmpty()) {
-						usedRegions++;
-						continue;
-					}
-					if (region.equals("?")) { //$NON-NLS-1$
-						currentIndex++;
-						usedRegions++;
-						continue;
-					}
-					int startlocation = indexOf(Pattern.compile(region), string.substring(currentIndex));
-					if (startlocation == -1) {
-						currentIndex = ++startingIndex;
-						positions = new ArrayList<>();
-						restart = true;
-						break;
-					}
-					int regionIndex = region.replace("\\\\", "1").replace("\\", "").length(); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
-					currentIndex += startlocation;
-					positions.add(new Position(currentIndex, regionIndex));
-					currentIndex += regionIndex;
-					usedRegions++;
+			if (regionsDontMatch) {
+				// We should get here only when CamelCase nor wildcard matching succeeded
+				// A simple comparison of the whole strings should succeed instead
+				if (string.toLowerCase().startsWith(matching.toLowerCase())) {
+					positions.add(new Position(0, matching.length()));
 				}
-			} while (restart && currentIndex < string.length());
-			if (usedRegions != regions.length && string.toLowerCase().startsWith(originalMatching.toLowerCase())) {
-				positions = new ArrayList<>();
-				positions.add(new Position(0, originalMatching.length()));
 			}
 			return positions;
 		}
 
-		private int indexOf(Pattern pattern, String s) {
-			Matcher matcher = pattern.matcher(s);
-			return matcher.find() ? matcher.start() : -1;
-		}
-
-		private String escapeRegexCharacters(String inputString) {
-			final List<Character> metaCharacters = Arrays.asList('\\', '^', '$', '{', '}', '[', ']', '(', ')', '+', '|',
-					'<', '>', '-', '&');
-			StringBuilder output = new StringBuilder();
-			for (char character : inputString.toCharArray()) {
-				if (metaCharacters.contains(character)) {
-					output.append('\\');
-				}
-				output.append(character);
-			}
-			return output.toString();
-		}
-
 		@Override
 		public void dispose() {
 			provider.removeListener(this);
@@ -791,8 +801,13 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 				return super.getImage(element);
 			}
 
-			IResource parent = ((IResource) element).getParent();
-			return provider.getImage(parent);
+			final IResource resource = (IResource) element;
+
+			if (parentIsRoot(resource)) {
+				return provider.getImage(resource);
+			}
+
+			return provider.getImage(resource.getParent());
 		}
 
 		@Override
@@ -806,7 +821,7 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 			if (parent.getType() == IResource.ROOT) {
 				// Get readable name for workspace root ("Workspace"), without
 				// duplicating language-specific string here.
-				return null;
+				return ((IResource) element).getName();
 			}
 
 			return parent.getFullPath().makeRelative().toString();
