@@ -21,7 +21,6 @@ import java.io.InputStream;
 import java.net.URI;
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.core.filesystem.EFS;
@@ -326,20 +325,15 @@ public final class IDE {
 	/**
 	 * Opens an editor on the given object.
 	 * <p>
-	 * If the page already has an editor open on the target object then that
-	 * editor is brought to front; otherwise, a new editor is opened.
-	 * <p>
+	 * If the page already has an editor open on the target object then that editor
+	 * is brought to front; otherwise, a new editor is opened.
+	 * </p>
 	 *
-	 * @param page
-	 *            the page in which the editor will be opened
-	 * @param input
-	 *            the editor input
-	 * @param editorId
-	 *            the id of the editor extension to use
-	 * @return an open editor or <code>null</code> if an external editor was
-	 *         opened
-	 * @exception PartInitException
-	 *                if the editor could not be initialized
+	 * @param page     the page in which the editor will be opened
+	 * @param input    the editor input
+	 * @param editorId the id of the editor extension to use
+	 * @return an open editor or <code>null</code> if an external editor was opened
+	 * @exception PartInitException if the editor could not be initialized
 	 * @see org.eclipse.ui.IWorkbenchPage#openEditor(IEditorInput, String)
 	 */
 	public static IEditorPart openEditor(IWorkbenchPage page,
@@ -465,25 +459,18 @@ public final class IDE {
 	/**
 	 * Opens an editor on the given object.
 	 * <p>
-	 * If the page already has an editor open on the target object then that
-	 * editor is brought to front; otherwise, a new editor is opened. If
+	 * If the page already has an editor open on the target object then that editor
+	 * is brought to front; otherwise, a new editor is opened. If
 	 * <code>activate == true</code> the editor will be activated.
-	 * <p>
+	 * </p>
 	 *
-	 * @param page
-	 *            the page in which the editor will be opened
-	 * @param input
-	 *            the editor input
-	 * @param editorId
-	 *            the id of the editor extension to use
-	 * @param activate
-	 *            if <code>true</code> the editor will be activated
-	 * @return an open editor or <code>null</code> if an external editor was
-	 *         opened
-	 * @exception PartInitException
-	 *                if the editor could not be initialized
-	 * @see org.eclipse.ui.IWorkbenchPage#openEditor(IEditorInput, String,
-	 *      boolean)
+	 * @param page     the page in which the editor will be opened
+	 * @param input    the editor input
+	 * @param editorId the id of the editor extension to use
+	 * @param activate if <code>true</code> the editor will be activated
+	 * @return an open editor or <code>null</code> if an external editor was opened
+	 * @exception PartInitException if the editor could not be initialized
+	 * @see org.eclipse.ui.IWorkbenchPage#openEditor(IEditorInput, String, boolean)
 	 */
 	public static IEditorPart openEditor(IWorkbenchPage page,
 			IEditorInput input, String editorId, boolean activate)
@@ -502,21 +489,17 @@ public final class IDE {
 	 * resolve the editor based on content-type bindings as well as traditional
 	 * name/extension bindings.
 	 * <p>
-	 * If the page already has an editor open on the target object then that
-	 * editor is brought to front; otherwise, a new editor is opened. If
+	 * If the page already has an editor open on the target object then that editor
+	 * is brought to front; otherwise, a new editor is opened. If
 	 * <code>activate == true</code> the editor will be activated.
-	 * <p>
+	 * </p>
 	 *
-	 * @param page
-	 *            the page in which the editor will be opened
-	 * @param input
-	 *            the editor input
-	 * @param activate
-	 *            if <code>true</code> the editor will be activated
-	 * @return an open editor or <code>null</code> if an external editor was
-	 *         opened or if opening was canceled
-	 * @exception PartInitException
-	 *                if the editor could not be initialized
+	 * @param page     the page in which the editor will be opened
+	 * @param input    the editor input
+	 * @param activate if <code>true</code> the editor will be activated
+	 * @return an open editor or <code>null</code> if an external editor was opened
+	 *         or if opening was canceled
+	 * @exception PartInitException if the editor could not be initialized
 	 * @see org.eclipse.ui.IWorkbenchPage#openEditor(org.eclipse.ui.IEditorInput,
 	 *      String, boolean)
 	 */
@@ -531,23 +514,18 @@ public final class IDE {
 	 * name/extension bindings if <code>determineContentType</code> is
 	 * <code>true</code>.
 	 * <p>
-	 * If the page already has an editor open on the target object then that
-	 * editor is brought to front; otherwise, a new editor is opened. If
+	 * If the page already has an editor open on the target object then that editor
+	 * is brought to front; otherwise, a new editor is opened. If
 	 * <code>activate == true</code> the editor will be activated.
-	 * <p>
+	 * </p>
 	 *
-	 * @param page
-	 *            the page in which the editor will be opened
-	 * @param input
-	 *            the editor input
-	 * @param activate
-	 *            if <code>true</code> the editor will be activated
-	 * @param determineContentType
-	 *            attempt to resolve the content type for this file
-	 * @return an open editor or <code>null</code> if an external editor was
-	 *         opened or if opening was canceled
-	 * @exception PartInitException
-	 *                if the editor could not be initialized
+	 * @param page                 the page in which the editor will be opened
+	 * @param input                the editor input
+	 * @param activate             if <code>true</code> the editor will be activated
+	 * @param determineContentType attempt to resolve the content type for this file
+	 * @return an open editor or <code>null</code> if an external editor was opened
+	 *         or if opening was canceled
+	 * @exception PartInitException if the editor could not be initialized
 	 * @see org.eclipse.ui.IWorkbenchPage#openEditor(org.eclipse.ui.IEditorInput,
 	 *      String, boolean)
 	 * @since 3.1
@@ -576,18 +554,15 @@ public final class IDE {
 	 * resolve the editor based on content-type bindings as well as traditional
 	 * name/extension bindings.
 	 * <p>
-	 * If the page already has an editor open on the target object then that
-	 * editor is brought to front; otherwise, a new editor is opened.
-	 * <p>
+	 * If the page already has an editor open on the target object then that editor
+	 * is brought to front; otherwise, a new editor is opened.
+	 * </p>
 	 *
-	 * @param page
-	 *            the page in which the editor will be opened
-	 * @param input
-	 *            the editor input
-	 * @return an open editor or <code>null</code> if an external editor was
-	 *         opened or if opening was canceled
-	 * @exception PartInitException
-	 *                if the editor could not be initialized
+	 * @param page  the page in which the editor will be opened
+	 * @param input the editor input
+	 * @return an open editor or <code>null</code> if an external editor was opened
+	 *         or if opening was canceled
+	 * @exception PartInitException if the editor could not be initialized
 	 * @see org.eclipse.ui.IWorkbenchPage#openEditor(IEditorInput, String)
 	 */
 	public static IEditorPart openEditor(IWorkbenchPage page, IFile input)
@@ -610,20 +585,15 @@ public final class IDE {
 	/**
 	 * Opens an editor on the given file resource.
 	 * <p>
-	 * If the page already has an editor open on the target object then that
-	 * editor is brought to front; otherwise, a new editor is opened.
-	 * <p>
+	 * If the page already has an editor open on the target object then that editor
+	 * is brought to front; otherwise, a new editor is opened.
+	 * </p>
 	 *
-	 * @param page
-	 *            the page in which the editor will be opened
-	 * @param input
-	 *            the editor input
-	 * @param editorId
-	 *            the id of the editor extension to use
-	 * @return an open editor or <code>null</code> if an external editor was
-	 *         opened
-	 * @exception PartInitException
-	 *                if the editor could not be initialized
+	 * @param page     the page in which the editor will be opened
+	 * @param input    the editor input
+	 * @param editorId the id of the editor extension to use
+	 * @return an open editor or <code>null</code> if an external editor was opened
+	 * @exception PartInitException if the editor could not be initialized
 	 * @see org.eclipse.ui.IWorkbenchPage#openEditor(IEditorInput, String)
 	 */
 	public static IEditorPart openEditor(IWorkbenchPage page, IFile input,
@@ -640,25 +610,18 @@ public final class IDE {
 	/**
 	 * Opens an editor on the given file resource.
 	 * <p>
-	 * If the page already has an editor open on the target object then that
-	 * editor is brought to front; otherwise, a new editor is opened. If
+	 * If the page already has an editor open on the target object then that editor
+	 * is brought to front; otherwise, a new editor is opened. If
 	 * <code>activate == true</code> the editor will be activated.
-	 * <p>
+	 * </p>
 	 *
-	 * @param page
-	 *            the page in which the editor will be opened
-	 * @param input
-	 *            the editor input
-	 * @param editorId
-	 *            the id of the editor extension to use
-	 * @param activate
-	 *            if <code>true</code> the editor will be activated
-	 * @return an open editor or <code>null</code> if an external editor was
-	 *         opened
-	 * @exception PartInitException
-	 *                if the editor could not be initialized
-	 * @see org.eclipse.ui.IWorkbenchPage#openEditor(IEditorInput, String,
-	 *      boolean)
+	 * @param page     the page in which the editor will be opened
+	 * @param input    the editor input
+	 * @param editorId the id of the editor extension to use
+	 * @param activate if <code>true</code> the editor will be activated
+	 * @return an open editor or <code>null</code> if an external editor was opened
+	 * @exception PartInitException if the editor could not be initialized
+	 * @see org.eclipse.ui.IWorkbenchPage#openEditor(IEditorInput, String, boolean)
 	 */
 	public static IEditorPart openEditor(IWorkbenchPage page, IFile input,
 			String editorId, boolean activate) throws PartInitException {
@@ -809,53 +772,48 @@ public final class IDE {
 	}
 
 	/**
-	 * Returns an editor id appropriate for opening the given file store.
+	 * Returns an editor descriptor appropriate for opening the given file store.
 	 * <p>
-	 * The editor descriptor is determined using a multi-step process. This
-	 * method will attempt to resolve the editor based on content-type bindings
-	 * as well as traditional name/extension bindings.
+	 * The editor descriptor is determined using a multi-step process. This method
+	 * will attempt to resolve the editor based on content-type bindings as well as
+	 * traditional name/extension bindings.
 	 * </p>
 	 * <ol>
 	 * <li>The workbench editor registry is consulted to determine if an editor
-	 * extension has been registered for the file type. If so, an instance of
-	 * the editor extension is opened on the file. See
+	 * extension has been registered for the file type. If so, an instance of the
+	 * editor extension is opened on the file. See
 	 * <code>IEditorRegistry.getDefaultEditor(String)</code>.</li>
-	 * <li>The preferred {@link IUnknownEditorStrategy} is consulted.</li>
-	 * <li>The {@link SystemEditorOrTextEditorStrategy} is consulted, whose
-	 * behavior is
+	 * <li>The preferred {@link IUnassociatedEditorStrategy} is consulted.</li>
+	 * <li>The {@link SystemEditorOrTextEditorStrategy} is consulted, whose behavior
+	 * is
 	 * <ol>
-	 * <li>The operating system is consulted to determine if an in-place
-	 * component editor is available (e.g. OLE editor on Win32 platforms).</li>
-	 * <li>The operating system is consulted to determine if an external editor
-	 * is available.</li>
-	 * <li>The workbench editor registry is consulted to determine if the
-	 * default text editor is available.</li></li>
+	 * <li>The operating system is consulted to determine if an in-place component
+	 * editor is available (e.g. OLE editor on Win32 platforms).</li>
+	 * <li>The operating system is consulted to determine if an external editor is
+	 * available.</li>
+	 * <li>The workbench editor registry is consulted to determine if the default
+	 * text editor is available.</li>
 	 * </ol>
+	 * </li>
 	 * </ol>
-	 * </p>
 	 *
-	 * @param fileStore
-	 *            the file store
-	 * @param allowInteractive
-	 *            Whether user interactions are allowed
-	 * @return the id of an editor, appropriate for opening the file
-	 * @throws PartInitException
-	 *             if no editor can be found
+	 * @param fileStore        the file store
+	 * @param allowInteractive Whether user interactions are allowed
+	 * @return editor descriptor of an editor, appropriate for opening the file
+	 * @throws PartInitException if no editor can be found
+	 * @since 3.16
 	 */
-	private static String getEditorId(IFileStore fileStore, boolean allowInteractive) throws PartInitException {
+	public static IEditorDescriptor getEditorDescriptorForFileStore(IFileStore fileStore, boolean allowInteractive)
+			throws PartInitException {
 		String name = fileStore.fetchInfo().getName();
 		if (name == null) {
 			throw new IllegalArgumentException();
 		}
 
 		IContentType contentType = null;
-		try {
-			try (InputStream is = fileStore.openInputStream(EFS.NONE, null)) {
-				contentType = Platform.getContentTypeManager().findContentTypeFor(is, name);
-			}
-		} catch (CoreException ex) {
-			// continue without content type
-		} catch (IOException ex) {
+		try (InputStream is = fileStore.openInputStream(EFS.NONE, null)) {
+			contentType = Platform.getContentTypeManager().findContentTypeFor(is, name);
+		} catch (CoreException | IOException ex) {
 			// continue without content type
 		}
 
@@ -864,7 +822,7 @@ public final class IDE {
 		IEditorDescriptor defaultEditor = editorReg.getDefaultEditor(name, contentType);
 		defaultEditor = overrideDefaultEditorAssociation(new FileStoreEditorInput(fileStore), contentType,
 				defaultEditor);
-		return getEditorDescriptor(name, editorReg, defaultEditor, allowInteractive).getId();
+		return getEditorDescriptor(name, editorReg, defaultEditor, allowInteractive);
 	}
 
 	/**
@@ -1119,7 +1077,7 @@ public final class IDE {
 	/**
 	 * Get the editor descriptor for a given name using the editorDescriptor
 	 * passed in as a default as a starting point. It may delegate computation
-	 * to the active {@link IUnknownEditorStrategy}.
+	 * to the active {@link IUnassociatedEditorStrategy}.
 	 *
 	 * @param name
 	 *            The name of the element to open.
@@ -1128,7 +1086,7 @@ public final class IDE {
 	 * @param defaultDescriptor
 	 *            IEditorDescriptor or <code>null</code>
 	 * @param allowInteractive
-	 *            Whether we ask selected {@link IUnknownEditorStrategy}, that
+	 *            Whether we ask selected {@link IUnassociatedEditorStrategy}, that
 	 *            can be interactive.
 	 * @return IEditorDescriptor
 	 * @throws PartInitException
@@ -1373,7 +1331,7 @@ public final class IDE {
 		IEditorInput input = getEditorInput(fileStore);
 		String editorId;
 		try {
-			editorId = getEditorId(fileStore, true);
+			editorId = getEditorDescriptorForFileStore(fileStore, true).getId();
 		} catch (OperationCanceledException ex) {
 			return null;
 		}
@@ -1421,9 +1379,7 @@ public final class IDE {
 		try {
 			is = fileStore.openInputStream(EFS.NONE, null);
 			contentTypes = Platform.getContentTypeManager().findContentTypesFor(is, name);
-		} catch (CoreException ex) {
-			// it's OK, ignore
-		} catch (IOException ex) {
+		} catch (CoreException | IOException ex) {
 			// it's OK, ignore
 		} finally {
 			if (is != null) {
@@ -1606,8 +1562,7 @@ public final class IDE {
 	 */
 	public static List<IResource> computeSelectedResources(IStructuredSelection originalSelection) {
 		List<IResource> resources = null;
-		for (Iterator<?> e = originalSelection.iterator(); e.hasNext();) {
-			Object next = e.next();
+		for (Object next : originalSelection) {
 			IResource resource = Adapters.adapt(next, IResource.class);
 			if (resource != null) {
 				if (resources == null) {
@@ -1808,6 +1763,7 @@ public final class IDE {
 		manager.registerAdapters(paFactory, IFolder.class);
 		manager.registerAdapters(paFactory, IFile.class);
 		manager.registerAdapters(paFactory, IMarker.class);
+		manager.registerAdapters(paFactory, IEditorPart.class);
 	}
 
 	private static boolean isIgnoredStatus(IStatus status,
