@@ -14,6 +14,7 @@
 package org.eclipse.ui.ide.dialogs;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
@@ -146,19 +147,19 @@ public class ResourceTreeAndListGroup extends EventManager {
 	private static int PREFERRED_HEIGHT = 150;
 
 	/**
-	 *	Create an instance of this class.  Use this constructor if you wish to specify
-	 *	the width and/or height of the combined widget (to only hard-code one of the
-	 *	sizing dimensions, specify the other dimension's value as -1)
+	 * Create an instance of this class. Use this constructor if you wish to specify
+	 * the width and/or height of the combined widget (to only hard-code one of the
+	 * sizing dimensions, specify the other dimension's value as -1)
 	 *
-	 * @param parent
-	 * @param rootObject
-	 * @param treeContentProvider
-	 * @param treeLabelProvider
-	 * @param listContentProvider
-	 * @param listLabelProvider
-	 * @param style
-	 * @param useHeightHint If true then use the height hint
-	 *  to make this group big enough
+	 * @param parent              the parent composite
+	 * @param rootObject          the root object to represent in the tree
+	 * @param treeContentProvider content provider for the tree part
+	 * @param treeLabelProvider   label provider for the tree elements
+	 * @param listContentProvider content provider for the list part
+	 * @param listLabelProvider   label provider for the list elements
+	 * @param style               style for the composite
+	 * @param useHeightHint       If true then use the height hint to make this
+	 *                            group big enough
 	 *
 	 */
 	public ResourceTreeAndListGroup(Composite parent, Object rootObject,
@@ -211,9 +212,8 @@ public class ResourceTreeAndListGroup extends EventManager {
 	 *	@param treeElement java.lang.Object
 	 */
 	private boolean areAllChildrenWhiteChecked(Object treeElement) {
-		Object[] children = treeContentProvider.getChildren(treeElement);
-		for (int i = 0; i < children.length; ++i) {
-			if (!whiteCheckedTreeItems.contains(children[i])) {
+		for (Object element : treeContentProvider.getChildren(treeElement)) {
+			if (!whiteCheckedTreeItems.contains(element)) {
 				return false;
 			}
 		}
@@ -408,12 +408,9 @@ public class ResourceTreeAndListGroup extends EventManager {
 						expandedTreeNodes.add(item);
 						if (whiteCheckedTreeItems.contains(item)) {
 							//If this is the first expansion and this is a white checked node then check the children
-							Object[] children = treeContentProvider
-									.getChildren(item);
-							for (int i = 0; i < children.length; ++i) {
+							for (Object child : treeContentProvider.getChildren(item)) {
 								if (!whiteCheckedTreeItems
-										.contains(children[i])) {
-									Object child = children[i];
+										.contains(child)) {
 									setWhiteChecked(child, true);
 									treeViewer.setChecked(child, true);
 									checkedStateStore.put(child,
@@ -523,12 +520,11 @@ public class ResourceTreeAndListGroup extends EventManager {
 	 */
 	public boolean isEveryItemChecked() {
 		//Iterate through the children of the root as the root is not in the store
-		Object[] children = treeContentProvider.getChildren(root);
-		for (int i = 0; i < children.length; ++i) {
-			if (!whiteCheckedTreeItems.contains(children[i])) {
-				if (!treeViewer.getGrayed(children[i]))
+		for (Object element : treeContentProvider.getChildren(root)) {
+			if (!whiteCheckedTreeItems.contains(element)) {
+				if (!treeViewer.getGrayed(element))
 					return false;
-				if (!isEveryChildrenChecked(children[i]))
+				if (!isEveryChildrenChecked(element))
 					return false;
 			}
 		}
@@ -549,12 +545,11 @@ public class ResourceTreeAndListGroup extends EventManager {
 			if (listItems.length != checked.size())
 				return false;
 		}
-		Object[] children = treeContentProvider.getChildren(treeElement);
-		for (int i = 0; i < children.length; ++i) {
-			if (!whiteCheckedTreeItems.contains(children[i])) {
-				if (!treeViewer.getGrayed(children[i]))
+		for (Object element : treeContentProvider.getChildren(treeElement)) {
+			if (!whiteCheckedTreeItems.contains(element)) {
+				if (!treeViewer.getGrayed(element))
 					return false;
-				if (!isEveryChildrenChecked(children[i]))
+				if (!isEveryChildrenChecked(element))
 					return false;
 			}
 		}
@@ -581,9 +576,7 @@ public class ResourceTreeAndListGroup extends EventManager {
 			@Override
 			public void filterElements(Object[] elements,
 					IProgressMonitor monitor) {
-				for (Object element : elements) {
-					returnValue.add(element);
-				}
+				returnValue.addAll(Arrays.asList(elements));
 			}
 		};
 
@@ -615,9 +608,7 @@ public class ResourceTreeAndListGroup extends EventManager {
 			@Override
 			public void filterElements(Object[] elements,
 					IProgressMonitor monitor) {
-				for (Object element : elements) {
-					returnValue.add(element);
-				}
+				returnValue.addAll(Arrays.asList(elements));
 			}
 		};
 
@@ -726,8 +717,9 @@ public class ResourceTreeAndListGroup extends EventManager {
 	}
 
 	/**
-	 *	Set the initial checked state of the passed list element to true.
-	 * @param element
+	 * Set the initial checked state of the passed list element to true.
+	 *
+	 * @param element the element to set
 	 */
 	public void initialCheckListItem(Object element) {
 		Object parent = treeContentProvider.getParent(element);
@@ -740,9 +732,10 @@ public class ResourceTreeAndListGroup extends EventManager {
 	}
 
 	/**
-	 * Set the initial checked state of the passed element to true,
-	 * as well as to all of its children and associated list elements
-	 * @param element
+	 * Set the initial checked state of the passed element to true, as well as to
+	 * all of its children and associated list elements
+	 *
+	 * @param element the element to set
 	 */
 	public void initialCheckTreeItem(Object element) {
 		treeItemChecked(element, true);
@@ -883,9 +876,10 @@ public class ResourceTreeAndListGroup extends EventManager {
 	}
 
 	/**
-	 * Select or de-select all of the elements in the tree depending on the value of the selection
-	 * boolean. Be sure to update the displayed files as well.
-	 * @param selection
+	 * Select or de-select all of the elements in the tree depending on the value of
+	 * the selection boolean. Be sure to update the displayed files as well.
+	 *
+	 * @param selection the new selection state
 	 */
 	public void setAllSelections(final boolean selection) {
 		//If there is no root there is nothing to select
@@ -906,10 +900,7 @@ public class ResourceTreeAndListGroup extends EventManager {
 	 * @param treeElement the element being updated
 	 */
 	private void setListForWhiteSelection(Object treeElement) {
-		List listItemsChecked = new ArrayList();
-		for (Object listItem : listContentProvider.getElements(treeElement)) {
-			listItemsChecked.add(listItem);
-		}
+		List listItemsChecked = new ArrayList(Arrays.asList(listContentProvider.getElements(treeElement)));
 		checkedStateStore.put(treeElement, listItemsChecked);
 	}
 
@@ -936,9 +927,10 @@ public class ResourceTreeAndListGroup extends EventManager {
 	}
 
 	/**
-	 * Set the root of the widget to be new Root. Regenerate all of the tables and lists from this
-	 * value.
-	 * @param newRoot
+	 * Set the root of the widget to be new Root. Regenerate all of the tables and
+	 * lists from this value.
+	 *
+	 * @param newRoot the new root object
 	 */
 	public void setRoot(Object newRoot) {
 		this.root = newRoot;
