@@ -18,10 +18,13 @@ package org.eclipse.ui.internal.ide;
 import java.io.File;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
+import java.util.Set;
 import java.util.function.Function;
 import java.util.regex.Pattern;
 import java.util.stream.Collectors;
@@ -56,11 +59,13 @@ import org.eclipse.swt.widgets.Menu;
 import org.eclipse.swt.widgets.MenuItem;
 import org.eclipse.swt.widgets.Monitor;
 import org.eclipse.swt.widgets.Shell;
+import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.forms.events.ExpansionAdapter;
 import org.eclipse.ui.forms.events.ExpansionEvent;
 import org.eclipse.ui.forms.widgets.ExpandableComposite;
 import org.eclipse.ui.forms.widgets.Form;
 import org.eclipse.ui.forms.widgets.FormToolkit;
+import org.osgi.framework.FrameworkUtil;
 
 /**
  * A dialog that prompts for a directory to use as a workspace.
@@ -323,13 +328,12 @@ public class ChooseWorkspaceDialog extends TitleAreaDialog {
 		layout.marginLeft = 14;
 		layout.spacing = 6;
 		panel.setLayout(layout);
-		recentWorkspacesLinks = new HashMap<>(launchData.getRecentWorkspaces().length);
+		List<String> recentWorkspaces = getRecentWorkspaces();
+		recentWorkspacesLinks = new HashMap<>(recentWorkspaces.size());
 		Map<String, String> uniqueWorkspaceNames = createUniqueWorkspaceNameMap();
 
-		List<String> recentWorkspacesList = Arrays.asList(launchData.getRecentWorkspaces()).stream()
-				.filter(s -> s != null && !s.isEmpty()).collect(Collectors.toList());
 		List<Entry<String, String>> sortedList = uniqueWorkspaceNames.entrySet().stream().sorted((e1, e2) -> Integer
-				.compare(recentWorkspacesList.indexOf(e1.getValue()), recentWorkspacesList.indexOf(e2.getValue())))
+				.compare(recentWorkspaces.indexOf(e1.getValue()), recentWorkspaces.indexOf(e2.getValue())))
 				.collect(Collectors.toList());
 
 		for (Entry<String, String> uniqueWorkspaceEntry : sortedList) {
@@ -372,16 +376,22 @@ public class ChooseWorkspaceDialog extends TitleAreaDialog {
 		Map<String, String> uniqueWorkspaceNameMap = new HashMap<>();
 
 		// Convert workspace paths to arrays of single path segments
-		List<String[]> splittedWorkspaceNames = Arrays.asList(launchData.getRecentWorkspaces()).stream()
+		List<String[]> splittedWorkspaceNames = getRecentWorkspaces().stream()
 				.filter(s -> s != null && !s.isEmpty()).map(s -> s.split(Pattern.quote(fileSeparator)))
 				.collect(Collectors.toList());
 
+		// bug 531611: prevent endless loops
+		int maxSegmentsCount = 0;
+		for (String[] strings : splittedWorkspaceNames) {
+			maxSegmentsCount = Math.max(0, strings.length);
+		}
+
 		// create and collect unique workspace keys produced from arrays,
 		// try to generate unique keys starting with the last segment of the
 		// workspace path, increasing number of segments if no unique names
 		// could be generated,
 		// loop until all array values are removed from array list
-		for (int i = 1; !splittedWorkspaceNames.isEmpty(); i++) {
+		for (int i = 1; !splittedWorkspaceNames.isEmpty() && i <= maxSegmentsCount; i++) {
 			final int c = i;
 
 			// Function which flattens arrays to (hopefully unique) keys
@@ -535,7 +545,7 @@ public class ChooseWorkspaceDialog extends TitleAreaDialog {
 	}
 
 	private void setInitialTextValues(Combo text) {
-		for (String recentWorkspace : launchData.getRecentWorkspaces()) {
+		for (String recentWorkspace : getRecentWorkspaces()) {
 			if (recentWorkspace != null) {
 				text.add(recentWorkspace);
 			}
@@ -554,7 +564,8 @@ public class ChooseWorkspaceDialog extends TitleAreaDialog {
 			return null;
 		}
 
-		IDialogSettings settings = IDEWorkbenchPlugin.getDefault().getDialogSettings();
+		IDialogSettings settings = PlatformUI
+				.getDialogSettingsProvider(FrameworkUtil.getBundle(ChooseWorkspaceDialog.class)).getDialogSettings();
 		IDialogSettings section = settings.getSection(DIALOG_SETTINGS_SECTION);
 		if (section == null) {
 			section = settings.addNewSection(DIALOG_SETTINGS_SECTION);
@@ -588,4 +599,41 @@ public class ChooseWorkspaceDialog extends TitleAreaDialog {
 	public Button getDefaultButton() {
 		return defaultButton;
 	}
+
+	@Override
+	protected boolean isResizable() {
+		return true;
+	}
+
+	private List<String> getRecentWorkspaces() {
+		String[] workspaces = launchData.getRecentWorkspaces();
+		return filterDuplicatedPaths(workspaces);
+	}
+
+	/**
+	 * Filters out duplicates in the specified {@code paths}. Duplicated paths are
+	 * paths that point to the same disk location, but have superfluous
+	 * {@link File#separator} symbols.
+	 *
+	 * @param paths The set of paths to filter.
+	 * @return The set of paths without duplicates.
+	 */
+	public static List<String> filterDuplicatedPaths(String[] paths) {
+		Set<String> normalizedPaths = new HashSet<>();
+		List<String> recentWorkspaces = new ArrayList<>();
+		for (String workspace : paths) {
+			if (workspace != null && !workspace.isEmpty()) {
+				String[] splitPath = workspace.split(Pattern.quote(File.separator));
+				String normalizedPath = Arrays.stream(splitPath).filter(s -> !s.isEmpty()).collect(Collectors.joining(File.separator));
+				if (workspace.startsWith(File.separator)) {
+					normalizedPath = File.separator + normalizedPath;
+				}
+				boolean nonDuplicate = normalizedPaths.add(normalizedPath);
+				if (nonDuplicate) {
+					recentWorkspaces.add(workspace);
+				}
+			}
+		}
+		return Collections.unmodifiableList(recentWorkspaces);
+	}
 }
