@@ -13,6 +13,7 @@
  *******************************************************************************/
 package org.eclipse.ui.internal.ide.actions;
 
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashSet;
 
@@ -61,9 +62,7 @@ public class BuildUtilities {
 				ResourceMapping mapping = ResourceUtil.getResourceMapping(currentSelection);
 				if (mapping != null) {
 					IProject[] theProjects = mapping.getProjects();
-					for (IProject theProject : theProjects) {
-						projects.add(theProject);
-					}
+					projects.addAll(Arrays.asList(theProjects));
 				} else {
 					IMarker marker = Adapters.adapt(currentSelection, IMarker.class, false);
 					if (marker != null) {
@@ -103,14 +102,12 @@ public class BuildUtilities {
 		IProject[] selected = null;
 		if (selection != null && !selection.isEmpty() && selection instanceof IStructuredSelection) {
 			selected = extractProjects(((IStructuredSelection) selection).toArray());
-		} else {
-			//see if we can extract a selected project from the active editor
-			if (activePart instanceof IEditorPart) {
-				IEditorPart editor= (IEditorPart)activePart;
-				IFile file = ResourceUtil.getFile(editor.getEditorInput());
-				if (file != null) {
-					selected = new IProject[] {file.getProject()};
-				}
+		} else //see if we can extract a selected project from the active editor
+		if (activePart instanceof IEditorPart) {
+			IEditorPart editor= (IEditorPart)activePart;
+			IFile file = ResourceUtil.getFile(editor.getEditorInput());
+			if (file != null) {
+				selected = new IProject[] {file.getProject()};
 			}
 		}
 		if (selected == null) {
