@@ -359,11 +359,10 @@ public class ResourceWorkingSetPage extends WizardPage implements IWorkingSetPag
 			}
 			tree.setCheckedElements(items);
 			for (Object i : items) {
-				IAdaptable item = null;
 				if (!(i instanceof IAdaptable)) {
 					continue;
 				}
-				item = (IAdaptable) i;
+				IAdaptable item = (IAdaptable) i;
 				IContainer container = Adapters.adapt(item, IContainer.class);
 
 				if (container != null) {
