@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -18,7 +18,6 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
 import java.util.ArrayList;
-import java.util.Iterator;
 
 import javax.xml.parsers.ParserConfigurationException;
 
@@ -87,9 +86,9 @@ public class WelcomeEditor extends EditorPart {
 
 	private WelcomeParser parser;
 
-	private ArrayList hyperlinkRanges = new ArrayList();
+	private ArrayList<StyleRange> hyperlinkRanges = new ArrayList<>();
 
-	private ArrayList texts = new ArrayList();
+	private ArrayList<StyledText> texts = new ArrayList<>();
 
 	private ScrolledComposite scrolledComposite;
 
@@ -134,34 +133,32 @@ public class WelcomeEditor extends EditorPart {
 	 * Finds the next text
 	 */
 	private StyledText nextText(StyledText text) {
-		int index = 0;
 		if (text == null) {
-			return (StyledText) texts.get(0);
+			return texts.get(0);
 		}
-		index = texts.indexOf(text);
+		int index = texts.indexOf(text);
 
 		//If we are not at the end....
 		if (index < texts.size() - 1) {
-			return (StyledText) texts.get(index + 1);
+			return texts.get(index + 1);
 		}
-		return (StyledText) texts.get(0);
+		return texts.get(0);
 	}
 
 	/**
 	 * Finds the previous text
 	 */
 	private StyledText previousText(StyledText text) {
-		int index = 0;
 		if (text == null) {
-			return (StyledText) texts.get(0);
+			return texts.get(0);
 		}
-		index = texts.indexOf(text);
+		int index = texts.indexOf(text);
 
 		//If we are at the beginning....
 		if (index == 0) {
-			return (StyledText) texts.get(texts.size() - 1);
+			return texts.get(texts.size() - 1);
 		}
-		return (StyledText) texts.get(index - 1);
+		return texts.get(index - 1);
 	}
 
 	/**
@@ -288,8 +285,7 @@ public class WelcomeEditor extends EditorPart {
 			}
 			StyledText text2 = (StyledText) e.widget;
 			WelcomeItem item = (WelcomeItem) e.widget.getData();
-			int offset = -1;
-			offset = text2.getOffsetAtPoint(new Point(e.x, e.y));
+			int offset = text2.getOffsetAtPoint(new Point(e.x, e.y));
 			if (offset == -1) {
 				text2.setCursor(null);
 			} else if (item.isLinkAt(offset)) {
@@ -610,7 +606,7 @@ public class WelcomeEditor extends EditorPart {
 					} else {
 						extent = w - adjust;
 					}
-					StyledText text = (StyledText) texts.get(i);
+					StyledText text = texts.get(i);
 					Point p1 = text.computeSize(extent, SWT.DEFAULT, false);
 					((GridData) text.getLayoutData()).widthHint = p1.x;
 				}
@@ -630,7 +626,7 @@ public class WelcomeEditor extends EditorPart {
 					VERT_SCROLL_INCREMENT);
 		} else {
 			GC gc = new GC(sampleStyledText);
-			int width = gc.getFontMetrics().getAverageCharWidth();
+			int width = (int) gc.getFontMetrics().getAverageCharacterWidth();
 			gc.dispose();
 			this.scrolledComposite.getHorizontalBar().setIncrement(width);
 			this.scrolledComposite.getVerticalBar().setIncrement(
@@ -647,6 +643,7 @@ public class WelcomeEditor extends EditorPart {
 	 * </p>
 	 * <p>
 	 * For implementors this is a multi-step process:
+	 * </p>
 	 * <ol>
 	 *   <li>Create one or more controls within the parent.</li>
 	 *   <li>Set the parent layout as needed.</li>
@@ -655,7 +652,6 @@ public class WelcomeEditor extends EditorPart {
 	 *   <li>Register a selection provider with the <code>ISelectionService</code>
 	 *     (optional). </li>
 	 * </ol>
-	 * </p>
 	 *
 	 * @param parent the parent control
 	 */
@@ -692,9 +688,7 @@ public class WelcomeEditor extends EditorPart {
 					.equals(JFacePreferences.HYPERLINK_COLOR)) {
 				Color fg = JFaceColors.getHyperlinkText(editorComposite
 						.getDisplay());
-				Iterator links = hyperlinkRanges.iterator();
-				while (links.hasNext()) {
-					StyleRange range = (StyleRange) links.next();
+				for (StyleRange range : hyperlinkRanges) {
 					range.foreground = fg;
 				}
 			}
@@ -923,9 +917,7 @@ public class WelcomeEditor extends EditorPart {
 	public void read(InputStream is) throws IOException {
 		try {
 			parser = new WelcomeParser();
-		} catch (ParserConfigurationException e) {
-			throw (IOException) (new IOException().initCause(e));
-		} catch (SAXException e) {
+		} catch (ParserConfigurationException | SAXException e) {
 			throw (IOException) (new IOException().initCause(e));
 		}
 		parser.parse(is);
