@@ -98,11 +98,14 @@ import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.actions.ActionFactory;
 import org.eclipse.ui.ide.IDE;
 import org.eclipse.ui.ide.ResourceUtil;
+import org.eclipse.ui.internal.WorkbenchPage;
+import org.eclipse.ui.internal.WorkbenchPlugin;
 import org.eclipse.ui.internal.ide.IDEWorkbenchPlugin;
 import org.eclipse.ui.internal.ide.StatusUtil;
 import org.eclipse.ui.menus.IMenuService;
 import org.eclipse.ui.operations.RedoActionHandler;
 import org.eclipse.ui.operations.UndoActionHandler;
+import org.eclipse.ui.part.ISetSelectionTarget;
 import org.eclipse.ui.part.MarkerTransfer;
 import org.eclipse.ui.part.ViewPart;
 import org.eclipse.ui.progress.IWorkbenchSiteProgressService;
@@ -1140,8 +1143,11 @@ public class ExtendedMarkersView extends ViewPart {
 
 	/**
 	 * Open the selected markers
+	 *
+	 * @since 3.18
 	 */
-	void openSelectedMarkers() {
+
+	protected void openSelectedMarkers() {
 		IMarker[] markers = getOpenableMarkers();
 		for (IMarker marker : markers) {
 			IWorkbenchPage page = getSite().getPage();
@@ -1149,6 +1155,29 @@ public class ExtendedMarkersView extends ViewPart {
 		}
 	}
 
+	/**
+	 * Checks if there is a filter currently enabled.
+	 *
+	 * @since 3.20
+	 *
+	 * @return true if a filter is enabled, false if no filter is enabled.
+	 *
+	 */
+	public boolean isFilterEnabled() {
+		return generator != null && generator.getEnabledFilters().size() > 0;
+	}
+
+	/**
+	 * Checks if there is a limit on the number of items displayed.
+	 *
+	 * @since 3.20
+	 *
+	 * @return true if a limits enabled, false if no limits.
+	 */
+	public boolean isMarkerLimitsEnabled() {
+		return generator != null && generator.isMarkerLimitsEnabled();
+	}
+
 	/**
 	 * Restore the expanded categories.
 	 *
@@ -1596,11 +1625,38 @@ public class ExtendedMarkersView extends ViewPart {
 
 		if (marker != null && marker.getResource() instanceof IFile) {
 			try {
-				IDE.openEditor(page, marker, OpenStrategy.activateOnOpen());
+				if (IDE.openEditor(page, marker, OpenStrategy.activateOnOpen()) != null) {
+					return;
+				}
 			} catch (PartInitException e) {
 				MarkerSupportInternalUtilities.showViewError(e);
 			}
 		}
+
+		showIn(marker, page, page.getPerspective().getDefaultShowIn());
+	}
+
+	private static boolean showIn(IMarker marker, IWorkbenchPage page, String targetPartId) {
+		if (targetPartId == null || WorkbenchPlugin.getDefault().getViewRegistry().find(targetPartId) == null) {
+			return false;
+		}
+		ISelection selection = new StructuredSelection(marker.getResource());
+		try {
+			IViewPart view = page.showView(targetPartId);
+			if (view == null) {
+				return false;
+			}
+			ISetSelectionTarget target = Adapters.adapt(view, ISetSelectionTarget.class);
+			if (target == null) {
+				return false;
+			}
+			target.selectReveal(selection);
+			((WorkbenchPage) page).performedShowIn(targetPartId);
+			return true;
+		} catch (PartInitException e) {
+			MarkerSupportInternalUtilities.showViewError(e);
+			return false;
+		}
 	}
 
 	/**
