@@ -10,30 +10,26 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Taimoor Mirza <taimoor.mrza@gmail.com> - Bug 549486
  *******************************************************************************/
 package org.eclipse.ui.internal.wizards.datatransfer;
 
-import java.io.BufferedInputStream;
-import java.io.BufferedOutputStream;
 import java.io.File;
-import java.io.FileOutputStream;
 import java.io.IOException;
-import java.io.InputStream;
-import java.io.OutputStream;
+import java.nio.file.Files;
+import java.nio.file.LinkOption;
+import java.nio.file.StandardCopyOption;
 
 import org.eclipse.core.resources.IContainer;
 import org.eclipse.core.resources.IFile;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
-import org.eclipse.ui.internal.ide.IDEWorkbenchPlugin;
 
 /**
  * Helper class for exporting resources to the file system.
  */
 public class FileSystemExporter {
-	private static final int DEFAULT_BUFFER_SIZE = 16*1024;
-
 	/**
 	 *  Creates the specified file system directory at <code>destinationPath</code>.
 	 *  This creates a new file system directory.
@@ -78,42 +74,9 @@ public class FileSystemExporter {
 	 *  file system
 	 */
 	protected void writeFile(IFile file, IPath destinationPath)
-			throws IOException, CoreException {
-		OutputStream output = null;
-		InputStream contentStream = null;
-
-		try {
-			contentStream = new BufferedInputStream(file.getContents(false));
-			output = new BufferedOutputStream(new FileOutputStream(destinationPath.toOSString()));
-			// for large files, need to make sure the chunk size can be handled by the VM
-			int available = contentStream.available();
-			available = available <= 0 ? DEFAULT_BUFFER_SIZE : available;
-			int chunkSize = Math.min(DEFAULT_BUFFER_SIZE, available);
-			byte[] readBuffer = new byte[chunkSize];
-			int n = contentStream.read(readBuffer);
-
-			while (n > 0) {
-				// only write the number of bytes read
-				output.write(readBuffer, 0, n);
-				n = contentStream.read(readBuffer);
-			}
-		} finally {
-			if (contentStream != null) {
-				// wrap in a try-catch to ensure attempt to close output stream
-				try {
-					contentStream.close();
-				}
-				catch(IOException e){
-					IDEWorkbenchPlugin
-							.log(
-									"Error closing input stream for file: " + file.getLocation(), e); //$NON-NLS-1$
-				}
-			}
-			if (output != null) {
-				// propogate this error to the user
-				output.close();
-			}
-		}
+			throws IOException {
+		Files.copy(file.getLocation().toFile().toPath(), destinationPath.toFile().toPath(),
+				StandardCopyOption.COPY_ATTRIBUTES, LinkOption.NOFOLLOW_LINKS);
 	}
 
 	/**
