@@ -547,16 +547,14 @@ public class ImportOperation extends WorkspaceModifyOperation {
 				targetResource.createLink(
 						createRelativePath(new Path(provider.getFullPath(fileObject)), targetResource), 0,
 						subMonitor.split(50));
-			} else {
-				if (targetResource.exists()) {
-					if (targetResource.isLinked()) {
-						targetResource.delete(true, subMonitor.split(50));
-						targetResource.create(contentStream, false, subMonitor.split(50));
-					} else
-						targetResource.setContents(contentStream, IResource.KEEP_HISTORY, subMonitor.split(100));
+			} else if (targetResource.exists()) {
+				if (targetResource.isLinked()) {
+					targetResource.delete(true, subMonitor.split(50));
+					targetResource.create(contentStream, false, subMonitor.split(50));
 				} else
-					targetResource.create(contentStream, false, subMonitor.split(100));
-			}
+					targetResource.setContents(contentStream, IResource.KEEP_HISTORY, subMonitor.split(100));
+			} else
+				targetResource.create(contentStream, false, subMonitor.split(100));
 			setResourceAttributes(targetResource, fileObject);
 
 			if (provider instanceof TarLeveledStructureProvider) {
