@@ -36,8 +36,6 @@ import org.eclipse.swt.SWTException;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Listener;
-import org.eclipse.ui.IWorkbench;
-import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.monitoring.IUiFreezeEventLogger;
 import org.eclipse.ui.monitoring.PreferenceConstants;
 import org.eclipse.ui.monitoring.StackSample;
@@ -689,12 +687,7 @@ public class EventLoopMonitorThread extends Thread {
 	}
 
 	private static Display getDisplay() throws IllegalStateException {
-		IWorkbench workbench = PlatformUI.getWorkbench();
-		if (workbench == null) {
-			throw new IllegalStateException(Messages.EventLoopMonitorThread_workbench_was_null);
-		}
-
-		Display display = workbench.getDisplay();
+		Display display = Display.getDefault();
 		if (display == null) {
 			throw new IllegalStateException(Messages.EventLoopMonitorThread_display_was_null);
 		}
