@@ -16,6 +16,10 @@ package org.eclipse.ui.internal.navigator.resources.workbench;
 
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Comparator;
+import java.util.Set;
+import java.util.SortedSet;
+import java.util.TreeSet;
 
 import org.eclipse.core.resources.IContainer;
 import org.eclipse.core.resources.IResource;
@@ -27,6 +31,7 @@ import org.eclipse.jface.viewers.AbstractTreeViewer;
 import org.eclipse.jface.viewers.StructuredViewer;
 import org.eclipse.jface.viewers.Viewer;
 import org.eclipse.swt.widgets.Control;
+import org.eclipse.ui.internal.navigator.resources.nested.PathComparator;
 import org.eclipse.ui.internal.navigator.resources.plugin.WorkbenchNavigatorPlugin;
 import org.eclipse.ui.model.WorkbenchContentProvider;
 
@@ -95,9 +100,28 @@ public class ResourceExtensionContentProvider extends WorkbenchContentProvider {
 			return;
 		}
 
+		final Collection<Runnable> runnables = new ArrayList<>();
+		final SortedSet<IResource> resourcesToRefresh = new TreeSet<>(new Comparator<IResource>() {
+			private PathComparator pathComparator = new PathComparator();
+			@Override
+			public int compare(IResource arg0, IResource arg1) {
+				return pathComparator.compare(arg0.getFullPath(), arg1.getFullPath());
+			}
+		});
+		processDelta(delta, runnables, resourcesToRefresh);
 
-		final Collection<Runnable> runnables = new ArrayList<Runnable>();
-		processDelta(delta, runnables);
+		IResource currentTopLevelResource = null;
+		for (IResource resource : resourcesToRefresh) {
+			if (resource == null) {
+				// paranoia, see bug 509821
+				continue;
+			}
+			if (currentTopLevelResource == null
+					|| !currentTopLevelResource.getFullPath().isPrefixOf(resource.getFullPath())) {
+				currentTopLevelResource = resource;
+				runnables.add(getRefreshRunnable(resource));
+			}
+		}
 
 		if (runnables.isEmpty()) {
 			return;
@@ -119,10 +143,13 @@ public class ResourceExtensionContentProvider extends WorkbenchContentProvider {
 		}
 
 	}
+
 	/**
-	 * Process a resource delta. Add any runnables
+	 * Process a resource delta. Add runnables for addAndRemove and
+	 * resourceToUpdate.
 	 */
-	private void processDelta(IResourceDelta delta, Collection<Runnable> runnables) {
+	private void processDelta(IResourceDelta delta, Collection<Runnable> addAndRemoveRunnables,
+			Set<IResource> toRefresh) {
 		//he widget may have been destroyed
 		// by the time this is run. Check for this and do nothing if so.
 		Control ctrl = viewer.getControl();
@@ -143,7 +170,7 @@ public class ResourceExtensionContentProvider extends WorkbenchContentProvider {
 				.getAffectedChildren(IResourceDelta.CHANGED);
 		for (IResourceDelta affectedChild : affectedChildren) {
 			if ((affectedChild.getFlags() & IResourceDelta.TYPE) != 0) {
-				runnables.add(getRefreshRunnable(resource));
+				toRefresh.add(resource);
 				return;
 			}
 		}
@@ -157,18 +184,21 @@ public class ResourceExtensionContentProvider extends WorkbenchContentProvider {
 			/* support the Closed Projects filter;
 			 * when a project is closed, it may need to be removed from the view.
 			 */
-			runnables.add(getRefreshRunnable(resource.getParent()));
+			IContainer parent = resource.getParent();
+			if (parent != null) {
+				toRefresh.add(parent);
+			}
 		}
 		// Replacing a resource may affect its label and its children
 		if ((changeFlags & IResourceDelta.REPLACED) != 0) {
-			runnables.add(getRefreshRunnable(resource));
+			toRefresh.add(resource);
 			return;
 		}
 
 
 		// Handle changed children .
 		for (IResourceDelta affectedChild : affectedChildren) {
-			processDelta(affectedChild, runnables);
+			processDelta(affectedChild, addAndRemoveRunnables, toRefresh);
 		}
 
 		// @issue several problems here:
@@ -256,7 +286,7 @@ public class ResourceExtensionContentProvider extends WorkbenchContentProvider {
 				((StructuredViewer) viewer).refresh(resource);
 			}
 		};
-		runnables.add(addAndRemove);
+		addAndRemoveRunnables.add(addAndRemove);
 	}
 
 	/**
