@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -751,7 +751,7 @@ public class EventDetailsDialog extends TrayDialog {
 
 		String filtersString = memento.getString(FILTER_LIST);
 
-		if ((filterEnabled == null) || (filterEnabled.booleanValue() == false) || filtersString == null) {
+		if ((filterEnabled == null) || (!filterEnabled.booleanValue()) || filtersString == null) {
 			return new String[0];
 		}
 
