@@ -69,7 +69,7 @@ public class TabbedPropertyList
 
 	private boolean focus = false;
 
-	private ListElement[] elements;
+	private ListElement[] elements = ELEMENTS_EMPTY;
 
 	/**
 	 * This map specifies the number of dynamic images for a tab. It has a
@@ -80,7 +80,7 @@ public class TabbedPropertyList
 	 * tab by using the showDynamicImage() and hideDynamicImage() methods on the
 	 * tab's ListElement object.
 	 */
-	private Map tabToDynamicImageCountMap;
+	private Map<ITabItem, Integer> tabToDynamicImageCountMap;
 
 	private int selectedElementIndex = NONE;
 
@@ -160,7 +160,7 @@ public class TabbedPropertyList
 			selected = false;
 			this.index = index;
 
-			addPaintListener(e -> paint(e));
+			addPaintListener(this::paint);
 			addMouseListener(new MouseAdapter() {
 
 				@Override
@@ -437,7 +437,7 @@ public class TabbedPropertyList
 		 */
 		public TopNavigationElement(Composite parent) {
 			super(parent, SWT.NO_FOCUS);
-			addPaintListener(e -> paint(e));
+			addPaintListener(this::paint);
 			addMouseListener(new MouseAdapter() {
 
 				@Override
@@ -520,7 +520,7 @@ public class TabbedPropertyList
 		 */
 		public BottomNavigationElement(Composite parent) {
 			super(parent, SWT.NO_FOCUS);
-			addPaintListener(e -> paint(e));
+			addPaintListener(this::paint);
 			addMouseListener(new MouseAdapter() {
 
 				@Override
@@ -710,10 +710,8 @@ public class TabbedPropertyList
 	 * Removes all elements from this list.
 	 */
 	public void removeAll() {
-		if (elements != null) {
-			for (ListElement element : elements) {
-				element.dispose();
-			}
+		for (ListElement element : elements) {
+			element.dispose();
 		}
 		elements = ELEMENTS_EMPTY;
 		selectedElementIndex = NONE;
@@ -732,7 +730,7 @@ public class TabbedPropertyList
 	 *
 	 * @param tabToDynamicImageCountMap
 	 */
-	public void setDynamicImageCount(Map tabToDynamicImageCountMap) {
+	public void setDynamicImageCount(Map<ITabItem, Integer> tabToDynamicImageCountMap) {
 		this.tabToDynamicImageCountMap = tabToDynamicImageCountMap;
 	}
 
@@ -754,8 +752,7 @@ public class TabbedPropertyList
 				int dynamicImageCount = 0;
 				if (tabToDynamicImageCountMap != null
 						&& tabToDynamicImageCountMap.containsKey(children[i])) {
-					dynamicImageCount = ((Integer) tabToDynamicImageCountMap
-							.get(children[i])).intValue();
+					dynamicImageCount = tabToDynamicImageCountMap.get(children[i]).intValue();
 				}
 				elements[i] = new ListElement(this, (ITabItem) children[i],
 						dynamicImageCount, i);
@@ -790,8 +787,7 @@ public class TabbedPropertyList
 		if (tabToDynamicImageCountMap != null) {
 			int dynamicImageCount = 0;
 			if (tabToDynamicImageCountMap.containsKey(tabItem)) {
-				dynamicImageCount = ((Integer) tabToDynamicImageCountMap
-						.get(tabItem)).intValue();
+				dynamicImageCount = tabToDynamicImageCountMap.get(tabItem).intValue();
 			}
 			if (dynamicImageCount > 0) {
 				/*
