@@ -581,7 +581,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 
 		contextMenuManager = new MenuManager();
 		contextMenuManager.setRemoveAllWhenShown(true);
-		contextMenuManager.addMenuListener(manager -> fillContextMenu(manager));
+		contextMenuManager.addMenuListener(this::fillContextMenu);
 
 		final Table table = tableViewer.getTable();
 		Menu menu = contextMenuManager.createContextMenu(table);
@@ -956,8 +956,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	 * Schedules progress message refresh.
 	 */
 	public void scheduleProgressMessageRefresh() {
-		if (filterJob.getState() != Job.RUNNING && refreshProgressMessageJob.getState() != Job.RUNNING)
-			refreshProgressMessageJob.scheduleProgressRefresh(null);
+		refreshProgressMessageJob.scheduleProgressRefresh(null);
 	}
 
 	@Override
@@ -1320,7 +1319,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 	 */
 	private class RefreshProgressMessageJob extends UIJob {
 
-		private GranualProgressMonitor progressMonitor;
+		private volatile GranualProgressMonitor progressMonitor;
 
 		/**
 		 * Creates a new instance of the class.
@@ -1334,8 +1333,11 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		@Override
 		public IStatus runInUIThread(IProgressMonitor monitor) {
 
-			if (!progressLabel.isDisposed())
+			if (!progressLabel.isDisposed()) {
 				progressLabel.setText(progressMonitor != null ? progressMonitor.getMessage() : EMPTY_STRING);
+			} else {
+				return Status.CANCEL_STATUS;
+			}
 
 			if (progressMonitor == null || progressMonitor.isDone()) {
 				return new Status(IStatus.CANCEL, PlatformUI.PLUGIN_ID, IStatus.CANCEL, EMPTY_STRING, null);
@@ -1994,7 +1996,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 
 		private SelectionHistory(String rootNodeName, String infoNodeName) {
 
-			historyList = Collections.synchronizedSet(new LinkedHashSet<Object>() {
+			historyList = Collections.synchronizedSet(new LinkedHashSet<>() {
 
 				private static final long serialVersionUID = 0L;
 
@@ -2480,7 +2482,7 @@ public abstract class FilteredItemsSelectionDialog extends SelectionStatusDialog
 		public Object removeHistoryElement(Object item) {
 			if (this.selectionHistory != null)
 				this.selectionHistory.remove(item);
-			if (filter == null || filter.getPattern().length() == 0) {
+			if (filter == null || filter.getPattern().isEmpty()) {
 				items.remove(item);
 				duplicates.remove(item);
 				this.lastSortedItems.remove(item);
