@@ -31,12 +31,12 @@ public class EditorHistory {
 	/**
 	 * The maximum of entries in the history.
 	 */
-	public static final int MAX_SIZE = 20;
+	public static final int MAX_SIZE = 100;
 
 	/**
 	 * The list of editor entries, in FIFO order.
 	 */
-	private ArrayList fifoList = new ArrayList(MAX_SIZE);
+	private ArrayList<EditorHistoryItem> fifoList = new ArrayList<>(MAX_SIZE);
 
 	/**
 	 * Constructs a new history.
@@ -89,9 +89,9 @@ public class EditorHistory {
 	 * considered.
 	 */
 	public void refresh() {
-		Iterator iter = fifoList.iterator();
+		Iterator<EditorHistoryItem> iter = fifoList.iterator();
 		while (iter.hasNext()) {
-			EditorHistoryItem item = (EditorHistoryItem) iter.next();
+			EditorHistoryItem item = iter.next();
 			if (item.isRestored()) {
 				IEditorInput input = item.getInput();
 				if (input != null && !input.exists()) {
@@ -115,9 +115,9 @@ public class EditorHistory {
 		if (input == null) {
 			return;
 		}
-		Iterator iter = fifoList.iterator();
+		Iterator<EditorHistoryItem> iter = fifoList.iterator();
 		while (iter.hasNext()) {
-			EditorHistoryItem item = (EditorHistoryItem) iter.next();
+			EditorHistoryItem item = iter.next();
 			if (item.matches(input)) {
 				iter.remove();
 			}
@@ -145,9 +145,7 @@ public class EditorHistory {
 	 * @param memento the memento to save the mru history in
 	 */
 	public IStatus saveState(IMemento memento) {
-		Iterator iterator = fifoList.iterator();
-		while (iterator.hasNext()) {
-			EditorHistoryItem item = (EditorHistoryItem) iterator.next();
+		for (EditorHistoryItem item : fifoList) {
 			if (item.canSave()) {
 				IMemento itemMemento = memento.createChild(IWorkbenchConstants.TAG_FILE);
 				item.saveState(itemMemento);
