@@ -302,11 +302,7 @@ public abstract class FilteredTableBaseHandler extends AbstractHandler implement
 			addKeyListener(table, dialog);
 			addTraverseListener(table);
 
-			while (!dialog.isDisposed()) {
-				if (!display.readAndDispatch()) {
-					display.sleep();
-				}
-			}
+			keepOpen(display, dialog);
 		} finally {
 			if (!dialog.isDisposed()) {
 				cancel(dialog);
@@ -315,6 +311,18 @@ public abstract class FilteredTableBaseHandler extends AbstractHandler implement
 		}
 	}
 
+	/**
+	 * Intended to be overwritten by test classes so the handler won't block the UI
+	 * thread
+	 */
+	protected void keepOpen(Display display, Shell dialog) {
+		while (!dialog.isDisposed()) {
+			if (!display.readAndDispatch()) {
+				display.sleep();
+			}
+		}
+	}
+
 	/**
 	 * Build a 1x1 px gray image to be used as separator. This color, halfway
 	 * between white and black, looks good both in Classic and in Dark Theme
