@@ -15,6 +15,7 @@ package org.eclipse.ui.internal;
 
 import java.util.ArrayList;
 import java.util.Iterator;
+import java.util.List;
 import org.eclipse.core.runtime.IConfigurationElement;
 import org.eclipse.core.runtime.dynamichelpers.IExtensionTracker;
 import org.eclipse.jface.action.AbstractGroupMarker;
@@ -43,7 +44,7 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 
 	private IWorkbenchWindow window;
 
-	private ArrayList adjunctContributions = new ArrayList(0);
+	private ArrayList<ActionSetContribution> adjunctContributions = new ArrayList<>(0);
 
 	/**
 	 * Used by the workbench window extension handler to unhook action sets from
@@ -89,19 +90,17 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 		readElements(new IConfigurationElement[] { set.getConfigElement() });
 
 		if (cache != null) {
-			for (int i = 0; i < cache.size(); i++) {
-				ActionSetContribution contribution = (ActionSetContribution) cache.get(i);
+			for (Object element : cache) {
+				ActionSetContribution contribution = (ActionSetContribution) element;
 				contribution.contribute(actionSet.getBars(), true, true);
 				if (contribution.isAdjunctContributor()) {
 					adjunctContributions.add(contribution);
 				}
 			}
 		}
-		for (int i = 0; i < adjunctContributions.size(); i++) {
-			ActionSetContribution contribution = (ActionSetContribution) adjunctContributions.get(i);
+		for (ActionSetContribution contribution : adjunctContributions) {
 			ActionSetActionBars bars = actionSet.getBars();
-			for (int j = 0; j < contribution.adjunctActions.size(); j++) {
-				ActionDescriptor adjunctAction = (ActionDescriptor) contribution.adjunctActions.get(j);
+			for (ActionDescriptor adjunctAction : contribution.adjunctActions) {
 				contribution.contributeAdjunctCoolbarAction(adjunctAction, bars);
 			}
 		}
@@ -201,7 +200,7 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 
 	/**
 	 */
-	/* package */static void processActionSets(ArrayList pluginActionSets, WorkbenchWindow window) {
+	/* package */static void processActionSets(List<PluginActionSet> pluginActionSets, WorkbenchWindow window) {
 		// Process the action sets in two passes. On the first pass the
 		// pluginActionSetBuilder
 		// will process base contributions and cache adjunct contributions. On the
@@ -209,7 +208,7 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 		// pass the adjunct contributions will be processed.
 		PluginActionSetBuilder[] builders = new PluginActionSetBuilder[pluginActionSets.size()];
 		for (int i = 0; i < pluginActionSets.size(); i++) {
-			PluginActionSet set = (PluginActionSet) pluginActionSets.get(i);
+			PluginActionSet set = pluginActionSets.get(i);
 			PluginActionSetBuilder builder = new PluginActionSetBuilder();
 			builder.readActionExtensions(set, window);
 			builders[i] = builder;
@@ -223,11 +222,9 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 	 */
 	protected void processAdjunctContributions() {
 		// Contribute the adjunct contributions.
-		for (int i = 0; i < adjunctContributions.size(); i++) {
-			ActionSetContribution contribution = (ActionSetContribution) adjunctContributions.get(i);
+		for (ActionSetContribution contribution : adjunctContributions) {
 			ActionSetActionBars bars = actionSet.getBars();
-			for (int j = 0; j < contribution.adjunctActions.size(); j++) {
-				ActionDescriptor adjunctAction = (ActionDescriptor) contribution.adjunctActions.get(j);
+			for (ActionDescriptor adjunctAction : contribution.adjunctActions) {
 				contribution.contributeAdjunctCoolbarAction(adjunctAction, bars);
 			}
 		}
@@ -254,8 +251,8 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 			// See bug 66374 for more details.
 			// WorkbenchPlugin.getDefault().getActionSetRegistry().addCache(set.getDesc().getId(),
 			// cache);
-			for (int i = 0; i < cache.size(); i++) {
-				ActionSetContribution contribution = (ActionSetContribution) cache.get(i);
+			for (Object element : cache) {
+				ActionSetContribution contribution = (ActionSetContribution) element;
 				contribution.contribute(actionSet.getBars(), true, true);
 				if (contribution.isAdjunctContributor()) {
 					adjunctContributions.add(contribution);
@@ -291,7 +288,7 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 
 		private WorkbenchWindow window;
 
-		protected ArrayList adjunctActions = new ArrayList(0);
+		protected ArrayList<ActionDescriptor> adjunctActions = new ArrayList<>(0);
 
 		/**
 		 * Create a new instance of <code>ActionSetContribution</code>.
@@ -334,15 +331,13 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 			IMenuManager menuMgr = bars.getMenuManager();
 			IToolBarManager toolBarMgr = bars.getToolBarManager();
 			if (menus != null && menuMgr != null) {
-				for (int i = 0; i < menus.size(); i++) {
-					IConfigurationElement menuElement = (IConfigurationElement) menus.get(i);
+				for (IConfigurationElement menuElement : menus) {
 					contributeMenu(menuElement, menuMgr, menuAppendIfMissing);
 				}
 			}
 
 			if (actions != null) {
-				for (int i = 0; i < actions.size(); i++) {
-					ActionDescriptor ad = (ActionDescriptor) actions.get(i);
+				for (ActionDescriptor ad : actions) {
 					if (menuMgr != null) {
 						contributeMenuAction(ad, menuMgr, menuAppendIfMissing);
 					}
@@ -591,7 +586,7 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 		// for dynamic UI
 		private void revokeActionSetFromMenu(IMenuManager menuMgr, String actionsetId) {
 			IContributionItem[] items = menuMgr.getItems();
-			ArrayList itemsToRemove = new ArrayList();
+			ArrayList<IContributionItem> itemsToRemove = new ArrayList<>();
 			String id;
 			for (IContributionItem item : items) {
 				if (item instanceof IMenuManager) {
@@ -613,9 +608,9 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 					}
 				}
 			}
-			Iterator iter = itemsToRemove.iterator();
+			Iterator<IContributionItem> iter = itemsToRemove.iterator();
 			while (iter.hasNext()) {
-				IContributionItem item = (IContributionItem) iter.next();
+				IContributionItem item = iter.next();
 				menuMgr.remove(item);
 			}
 			menuMgr.update(true);
@@ -624,7 +619,7 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 		// for dynamic UI
 		private void revokeActionSetFromCoolbar(ICoolBarManager coolbarMgr, String actionsetId) {
 			IContributionItem[] items = coolbarMgr.getItems();
-			ArrayList itemsToRemove = new ArrayList();
+			ArrayList<IContributionItem> itemsToRemove = new ArrayList<>();
 			String id;
 			for (IContributionItem item : items) {
 				id = item.getId();
@@ -646,9 +641,9 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 					}
 				}
 			}
-			Iterator iter = itemsToRemove.iterator();
+			Iterator<IContributionItem> iter = itemsToRemove.iterator();
 			while (iter.hasNext()) {
-				coolbarMgr.remove((IContributionItem) iter.next());
+				coolbarMgr.remove(iter.next());
 			}
 			coolbarMgr.update(true);
 		}
@@ -656,7 +651,7 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 		// for dynamic UI
 		private void revokeActionSetFromToolbar(IToolBarManager toolbarMgr, String actionsetId) {
 			IContributionItem[] items = toolbarMgr.getItems();
-			ArrayList itemsToRemove = new ArrayList();
+			ArrayList<IContributionItem> itemsToRemove = new ArrayList<>();
 			String id;
 			for (IContributionItem item : items) {
 				id = item.getId();
@@ -681,9 +676,9 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 					}
 				}
 			}
-			Iterator iter = itemsToRemove.iterator();
+			Iterator<IContributionItem> iter = itemsToRemove.iterator();
 			while (iter.hasNext()) {
-				toolbarMgr.remove((IContributionItem) iter.next());
+				toolbarMgr.remove(iter.next());
 			}
 			toolbarMgr.update(true);
 		}
@@ -704,12 +699,11 @@ public class PluginActionSetBuilder extends PluginActionBuilder {
 		String id = set.getDesc().getId();
 
 		if (cache != null) {
-			for (int i = 0; i < cache.size(); i++) {
-				ActionSetContribution contribution = (ActionSetContribution) cache.get(i);
+			for (Object element : cache) {
+				ActionSetContribution contribution = (ActionSetContribution) element;
 				contribution.revokeContribution((WorkbenchWindow) window, actionSet.getBars(), id);
 				if (contribution.isAdjunctContributor()) {
-					for (int j = 0; j < contribution.adjunctActions.size(); j++) {
-						ActionDescriptor adjunctAction = (ActionDescriptor) contribution.adjunctActions.get(j);
+					for (ActionDescriptor adjunctAction : contribution.adjunctActions) {
 						contribution.revokeAdjunctCoolbarAction(adjunctAction, actionSet.getBars());
 					}
 				}
