@@ -16,10 +16,8 @@ package org.eclipse.ui.internal.actions;
 
 import java.util.ArrayList;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-
 import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.swt.events.MenuAdapter;
@@ -122,7 +120,7 @@ public abstract class AbstractWorkingSetPulldownDelegate
 	protected IWorkingSet[][] splitSets() {
 		IWorkingSet[] allSets = getWindow().getWorkbench().getWorkingSetManager().getWorkingSets();
 
-		Map map = new HashMap();
+		Map<String, List<IWorkingSet>> map = new HashMap<>();
 		WorkingSetRegistry registry = WorkbenchPlugin.getDefault().getWorkingSetRegistry();
 
 		for (IWorkingSet allSet : allSets) {
@@ -130,18 +128,18 @@ public abstract class AbstractWorkingSetPulldownDelegate
 			if (WorkbenchActivityHelper.filterItem(registry.getWorkingSetDescriptor(setType))) {
 				continue;
 			}
-			List setsOfType = (List) map.get(setType);
+			List<IWorkingSet> setsOfType = map.get(setType);
 			if (setsOfType == null) {
-				setsOfType = new ArrayList();
+				setsOfType = new ArrayList<>();
 				map.put(setType, setsOfType);
 			}
 			setsOfType.add(allSet);
 		}
 
-		IWorkingSet[][] typedSets = new IWorkingSet[map.keySet().size()][];
+		IWorkingSet[][] typedSets = new IWorkingSet[map.size()][];
 		int i = 0;
-		for (Iterator iter = map.keySet().iterator(); iter.hasNext();) {
-			List setsOfType = (List) map.get(iter.next());
+		for (Map.Entry<String, List<IWorkingSet>> entry : map.entrySet()) {
+			List<IWorkingSet> setsOfType = entry.getValue();
 			typedSets[i] = new IWorkingSet[setsOfType.size()];
 			setsOfType.toArray(typedSets[i++]);
 		}
