@@ -61,7 +61,7 @@ import org.eclipse.ui.internal.registry.IWorkbenchRegistryConstants;
 /**
  * Implementation of
  * {@link org.eclipse.ui.activities.IWorkbenchActivitySupport}.
- * 
+ *
  * @since 3.0
  */
 public class WorkbenchActivitySupport implements IWorkbenchActivitySupport, IExtensionChangeHandler {
@@ -230,9 +230,7 @@ public class WorkbenchActivitySupport implements IWorkbenchActivitySupport, IExt
 									.asyncExec(() -> BusyIndicator.showWhile(workbench.getDisplay(), () -> {
 										try {
 											dialog.run(false, false, runnable);
-										} catch (InvocationTargetException e1) {
-											log(e1);
-										} catch (InterruptedException e2) {
+										} catch (InvocationTargetException | InterruptedException e2) {
 											log(e2);
 										}
 									}));
