@@ -123,16 +123,14 @@ public final class CommandImageManager extends EventManager {
 				final Map styleMap = (Map) typedImage;
 				styleMap.put(style, descriptor);
 			}
-		} else {
-			if (typedImage instanceof Map) {
-				final Map styleMap = (Map) typedImage;
-				styleMap.put(style, descriptor);
-			} else if (typedImage instanceof ImageDescriptor || typedImage == null) {
-				final Map styleMap = new HashMap();
-				styleMap.put(null, typedImage);
-				styleMap.put(style, descriptor);
-				images[type] = styleMap;
-			}
+		} else if (typedImage instanceof Map) {
+			final Map styleMap = (Map) typedImage;
+			styleMap.put(style, descriptor);
+		} else if (typedImage instanceof ImageDescriptor || typedImage == null) {
+			final Map styleMap = new HashMap();
+			styleMap.put(null, typedImage);
+			styleMap.put(style, descriptor);
+			images[type] = styleMap;
 		}
 
 		fireManagerChanged(new CommandImageManagerEvent(this, new String[] { commandId }, type, style));
