@@ -26,6 +26,7 @@ import org.eclipse.core.runtime.IConfigurationElement;
 import org.eclipse.core.runtime.IExtensionDelta;
 import org.eclipse.core.runtime.IExtensionRegistry;
 import org.eclipse.core.runtime.IRegistryChangeEvent;
+import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.e4.core.commands.internal.HandlerServiceImpl;
 import org.eclipse.e4.ui.internal.workbench.Parameter;
@@ -88,7 +89,7 @@ public final class CommandPersistence extends RegistryPersistence {
 					WorkbenchMessages.CommandService_AutogeneratedCategoryDescription);
 		}
 
-		final List warningsToLog = new ArrayList(1);
+		final List<IStatus> warningsToLog = new ArrayList<>(1);
 
 		for (int i = 0; i < configurationElementCount; i++) {
 			final IConfigurationElement configurationElement = configurationElements[i];
@@ -135,7 +136,7 @@ public final class CommandPersistence extends RegistryPersistence {
 	 */
 	private static void readCommandsFromRegistry(final IConfigurationElement[] configurationElements,
 			final int configurationElementCount, final CommandManager commandManager) {
-		final List warningsToLog = new ArrayList(1);
+		final List<IStatus> warningsToLog = new ArrayList<>(1);
 
 		for (int i = 0; i < configurationElementCount; i++) {
 			final IConfigurationElement configurationElement = configurationElements[i];
@@ -157,9 +158,9 @@ public final class CommandPersistence extends RegistryPersistence {
 
 			// Read out the category id.
 			String categoryId = configurationElement.getAttribute(ATT_CATEGORY_ID);
-			if ((categoryId == null) || (categoryId.length() == 0)) {
+			if ((categoryId == null) || (categoryId.isEmpty())) {
 				categoryId = configurationElement.getAttribute(ATT_CATEGORY);
-				if ((categoryId != null) && (categoryId.length() == 0)) {
+				if ((categoryId != null) && (categoryId.isEmpty())) {
 					categoryId = null;
 				}
 			}
@@ -222,7 +223,7 @@ public final class CommandPersistence extends RegistryPersistence {
 	 *         <code>null</code> if none can be found.
 	 */
 	private static Parameter[] readParameters(final IConfigurationElement configurationElement,
-			final List warningsToLog, final CommandManager commandManager) {
+			final List<IStatus> warningsToLog, final CommandManager commandManager) {
 		final IConfigurationElement[] parameterElements = configurationElement.getChildren(TAG_COMMAND_PARAMETER);
 		if ((parameterElements == null) || (parameterElements.length == 0)) {
 			return null;
@@ -290,7 +291,7 @@ public final class CommandPersistence extends RegistryPersistence {
 	private static void readParameterTypesFromRegistry(final IConfigurationElement[] configurationElements,
 			final int configurationElementCount, final CommandManager commandManager) {
 
-		final List warningsToLog = new ArrayList(1);
+		final List<IStatus> warningsToLog = new ArrayList<>(1);
 
 		for (int i = 0; i < configurationElementCount; i++) {
 			final IConfigurationElement configurationElement = configurationElements[i];
@@ -343,7 +344,7 @@ public final class CommandPersistence extends RegistryPersistence {
 	 * @param command              The command for which the state is being read;
 	 *                             may be <code>null</code>.
 	 */
-	private static void readState(final IConfigurationElement configurationElement, final List warningsToLog,
+	private static void readState(final IConfigurationElement configurationElement, final List<IStatus> warningsToLog,
 			final Command command) {
 		final IConfigurationElement[] stateElements = configurationElement.getChildren(TAG_STATE);
 		if ((stateElements == null) || (stateElements.length == 0)) {
