@@ -17,7 +17,6 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Hashtable;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import org.eclipse.core.runtime.CoreException;
@@ -81,7 +80,7 @@ class NewWizardNewPage implements ISelectionChangedListener {
 	private WizardPatternFilter filteredTreeFilter;
 
 	// Keep track of the wizards we have previously selected
-	private Hashtable selectedWizards = new Hashtable();
+	private Hashtable<IWizardDescriptor, WorkbenchWizardNode> selectedWizards = new Hashtable<>();
 
 	private IDialogSettings settings;
 
@@ -93,7 +92,7 @@ class NewWizardNewPage implements ISelectionChangedListener {
 
 	private CLabel descImageCanvas;
 
-	private Map imageTable = new HashMap();
+	private Map<ImageDescriptor, Image> imageTable = new HashMap<>();
 
 	private IWizardDescriptor selectedElement;
 
@@ -107,7 +106,7 @@ class NewWizardNewPage implements ISelectionChangedListener {
 
 	/**
 	 * Create an instance of this class
-	 * 
+	 *
 	 * @param mainPage
 	 * @param wizardCategories
 	 * @param primaryWizards
@@ -166,7 +165,7 @@ class NewWizardNewPage implements ISelectionChangedListener {
 	 * Remove all primary wizards that are not in the wizard collection
 	 */
 	private void trimPrimaryWizards() {
-		ArrayList newPrimaryWizards = new ArrayList(primaryWizards.length);
+		ArrayList<IWizardDescriptor> newPrimaryWizards = new ArrayList<>(primaryWizards.length);
 
 		if (wizardCategories == null) {
 			return;// No categories so nothing to trim
@@ -178,7 +177,7 @@ class NewWizardNewPage implements ISelectionChangedListener {
 			}
 		}
 
-		primaryWizards = (WorkbenchWizardElement[]) newPrimaryWizards
+		primaryWizards = newPrimaryWizards
 				.toArray(new WorkbenchWizardElement[newPrimaryWizards.size()]);
 	}
 
@@ -295,7 +294,7 @@ class NewWizardNewPage implements ISelectionChangedListener {
 
 		filteredTreeFilter = new WizardPatternFilter();
 		FilteredTree filterTree = new FilteredTree(composite, SWT.SINGLE | SWT.H_SCROLL | SWT.V_SCROLL | SWT.BORDER,
-				filteredTreeFilter, true);
+				filteredTreeFilter, true, true);
 		filterTree.setQuickSelectionMode(true);
 
 		final TreeViewer treeViewer = filterTree.getViewer();
@@ -304,19 +303,15 @@ class NewWizardNewPage implements ISelectionChangedListener {
 		treeViewer.setComparator(NewWizardCollectionComparator.INSTANCE);
 		treeViewer.addSelectionChangedListener(this);
 
-		ArrayList inputArray = new ArrayList();
+		ArrayList<Object> inputArray = new ArrayList<>();
 
-		for (IWizardDescriptor primaryWizard : primaryWizards) {
-			inputArray.add(primaryWizard);
-		}
+		inputArray.addAll(Arrays.asList(primaryWizards));
 
 		boolean expandTop = false;
 
 		if (wizardCategories != null) {
 			if (wizardCategories.getParent() == null) {
-				for (IWizardCategory wizardCategory : wizardCategories.getCategories()) {
-					inputArray.add(wizardCategory);
-				}
+				inputArray.addAll(Arrays.asList(wizardCategories.getCategories()));
 			} else {
 				expandTop = true;
 				inputArray.add(wizardCategories);
@@ -330,7 +325,6 @@ class NewWizardNewPage implements ISelectionChangedListener {
 		}
 
 		AdaptableList input = new AdaptableList(inputArray);
-
 		treeViewer.setInput(input);
 
 		filterTree.setBackground(parent.getDisplay().getSystemColor(SWT.COLOR_WIDGET_BACKGROUND));
@@ -424,7 +418,7 @@ class NewWizardNewPage implements ISelectionChangedListener {
 							// 'show all' state but not the 'no show all' state
 							// (because they didnt exist).
 							Object[] newExpanded = filteredTree.getViewer().getExpandedElements();
-							List deltaList = new ArrayList(Arrays.asList(delta));
+							List<Object> deltaList = new ArrayList<>(Arrays.asList(delta));
 							deltaList.removeAll(Arrays.asList(newExpanded));
 						}
 					} finally {
@@ -452,8 +446,8 @@ class NewWizardNewPage implements ISelectionChangedListener {
 
 		// hook a listener to get rid of cached images.
 		descImageCanvas.addDisposeListener(e -> {
-			for (Iterator i = imageTable.values().iterator(); i.hasNext();) {
-				((Image) i.next()).dispose();
+			for (Image image : imageTable.values()) {
+				image.dispose();
 			}
 			imageTable.clear();
 		});
@@ -470,7 +464,7 @@ class NewWizardNewPage implements ISelectionChangedListener {
 			return;
 		}
 
-		List categoriesToExpand = new ArrayList(expandedCategoryPaths.length);
+		List<IWizardCategory> categoriesToExpand = new ArrayList<>(expandedCategoryPaths.length);
 
 		if (wizardCategories != null) {
 			for (String expandedCategoryPath : expandedCategoryPaths) {
@@ -590,14 +584,14 @@ class NewWizardNewPage implements ISelectionChangedListener {
 	 */
 	protected void storeExpandedCategories() {
 		Object[] expandedElements = filteredTree.getViewer().getExpandedElements();
-		List expandedElementPaths = new ArrayList(expandedElements.length);
+		List<String> expandedElementPaths = new ArrayList<>(expandedElements.length);
 		for (Object expandedElement : expandedElements) {
 			if (expandedElement instanceof IWizardCategory) {
 				expandedElementPaths.add(((IWizardCategory) expandedElement).getPath().toString());
 			}
 		}
 		settings.put(STORE_EXPANDED_CATEGORIES_ID,
-				(String[]) expandedElementPaths.toArray(new String[expandedElementPaths.size()]));
+				expandedElementPaths.toArray(new String[expandedElementPaths.size()]));
 	}
 
 	/**
@@ -641,7 +635,7 @@ class NewWizardNewPage implements ISelectionChangedListener {
 				GridData data = (GridData) descImageCanvas.getLayoutData();
 				data.widthHint = SWT.DEFAULT;
 				data.heightHint = SWT.DEFAULT;
-				Image image = (Image) imageTable.get(descriptor);
+				Image image = imageTable.get(descriptor);
 				if (image == null) {
 					image = descriptor.createImage(false);
 					imageTable.put(descriptor, image);
@@ -689,7 +683,7 @@ class NewWizardNewPage implements ISelectionChangedListener {
 		selectedElement = selectedObject;
 		WorkbenchWizardNode selectedNode;
 		if (selectedWizards.containsKey(selectedObject)) {
-			selectedNode = (WorkbenchWizardNode) selectedWizards.get(selectedObject);
+			selectedNode = selectedWizards.get(selectedObject);
 		} else {
 			selectedNode = new WorkbenchWizardNode(page, selectedObject) {
 				@Override
