@@ -17,7 +17,6 @@
 package org.eclipse.ui.internal.dialogs;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 import org.eclipse.e4.core.contexts.IEclipseContext;
 import org.eclipse.e4.ui.internal.workbench.swt.WorkbenchSWTActivator;
@@ -211,7 +210,7 @@ public class ShowViewDialog extends Dialog implements ISelectionChangedListener,
 	private void createFilteredTreeViewer(Composite parent) {
 		PatternFilter filter = new ViewPatternFilter();
 		int styleBits = SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL | SWT.BORDER;
-		filteredTree = new FilteredTree(parent, styleBits, filter, true);
+		filteredTree = new FilteredTree(parent, styleBits, filter, true, true);
 		filteredTree.setQuickSelectionMode(true);
 		filteredTree.setBackground(parent.getDisplay().getSystemColor(SWT.COLOR_WIDGET_BACKGROUND));
 
@@ -219,7 +218,6 @@ public class ShowViewDialog extends Dialog implements ISelectionChangedListener,
 		Control treeControl = treeViewer.getControl();
 		RGB dimmedRGB = blend(treeControl.getForeground().getRGB(), treeControl.getBackground().getRGB(), 60);
 		dimmedForeground = new Color(treeControl.getDisplay(), dimmedRGB);
-		treeControl.addDisposeListener(e -> dimmedForeground.dispose());
 
 		treeViewer
 				.setLabelProvider(new ViewLabelProvider(context, modelService, partService, window, dimmedForeground));
@@ -322,7 +320,7 @@ public class ShowViewDialog extends Dialog implements ISelectionChangedListener,
 			return;
 
 		if (expandedCategoryIds.length > 0)
-			filteredTree.getViewer().setExpandedElements(expandedCategoryIds);
+			filteredTree.getViewer().setExpandedElements((Object[]) expandedCategoryIds);
 
 		String selectedPartId = settings.get(STORE_SELECTED_VIEW_ID);
 		if (selectedPartId != null) {
@@ -398,9 +396,7 @@ public class ShowViewDialog extends Dialog implements ISelectionChangedListener,
 	 */
 	protected void updateSelection(SelectionChangedEvent event) {
 		ArrayList<MPartDescriptor> descs = new ArrayList<>();
-		IStructuredSelection sel = event.getStructuredSelection();
-		for (Iterator<?> i = sel.iterator(); i.hasNext();) {
-			Object o = i.next();
+		for (Object o : event.getStructuredSelection()) {
 			if (o instanceof MPartDescriptor) {
 				descs.add((MPartDescriptor) o);
 			}
@@ -425,7 +421,7 @@ public class ShowViewDialog extends Dialog implements ISelectionChangedListener,
 				if (o instanceof MPartDescriptor) {
 					String description = ((MPartDescriptor) o).getTooltip();
 					description = LocalizationHelper.getLocalized(description, (MPartDescriptor) o, context);
-					if (description != null && description.length() == 0)
+					if (description != null && description.isEmpty())
 						description = WorkbenchMessages.ShowView_noDesc;
 					popUp(description);
 				}
