@@ -25,7 +25,7 @@ import org.eclipse.jface.viewers.ITreeContentProvider;
 import org.eclipse.jface.viewers.Viewer;
 import org.eclipse.ui.activities.WorkbenchActivityHelper;
 import org.eclipse.ui.internal.WorkbenchPlugin;
-import org.eclipse.ui.internal.intro.IIntroConstants;
+import org.eclipse.ui.internal.e4.compatibility.CompatibilityPart;
 import org.eclipse.ui.views.IViewDescriptor;
 import org.eclipse.ui.views.IViewRegistry;
 
@@ -35,7 +35,7 @@ import org.eclipse.ui.views.IViewRegistry;
 public class ViewContentProvider implements ITreeContentProvider {
 
 	/**
-	 * Child cache. Map from Object->Object[]. Our hasChildren() method is expensive
+	 * Child cache. Map from Object-&gt;Object[]. Our hasChildren() method is expensive
 	 * so it's better to cache the results of getChildren().
 	 */
 	private Map<Object, Object[]> childMap = new HashMap<>();
@@ -112,7 +112,7 @@ public class ViewContentProvider implements ITreeContentProvider {
 		List<MPartDescriptor> descriptors = application.getDescriptors();
 		Set<MPartDescriptor> categoryDescriptors = new HashSet<>();
 		for (MPartDescriptor descriptor : descriptors) {
-			if (isFilteredByActivity(descriptor.getElementId()) || isIntroView(descriptor.getElementId())) {
+			if (isFilteredByActivity(descriptor)) {
 				continue;
 			}
 			String category = descriptor.getCategory();
@@ -133,7 +133,7 @@ public class ViewContentProvider implements ITreeContentProvider {
 		for (MPartDescriptor descriptor : descriptors) {
 			// only process views and hide views which are filtered by
 			// activities
-			if (!isView(descriptor) || isFilteredByActivity(descriptor.getElementId())) {
+			if (!isView(descriptor) || isFilteredByActivity(descriptor)) {
 				continue;
 			}
 
@@ -167,26 +167,22 @@ public class ViewContentProvider implements ITreeContentProvider {
 	}
 
 	/**
-	 * Remove Eclipse introview from this list, as it opened via the Help -> Welcome
-	 * menu
-	 */
-	private boolean isIntroView(String id) {
-		return (id.equals(IIntroConstants.INTRO_VIEW_ID));
-	}
-
-	/**
-	 * Evaluates if the view is filtered by an activity
+	 * Evaluates if the view is filtered by an activity. Note that this is only
+	 * possible for E3 views, as activities don't exist in the Eclipse 4.
 	 *
-	 * @param elementId
+	 * @param descriptor
 	 * @return result of the check
 	 */
-	private boolean isFilteredByActivity(String elementId) {
-		IViewDescriptor[] views = viewRegistry.getViews();
-		for (IViewDescriptor descriptor : views) {
-			if (descriptor.getId().equals(elementId) && WorkbenchActivityHelper.filterItem(descriptor)) {
-				return true;
-			}
-		}
-		return false;
+	private boolean isFilteredByActivity(MPartDescriptor descriptor) {
+		IViewDescriptor view = viewRegistry.find(descriptor.getElementId());
+
+		// viewRegistry.find(...) already applies a filtering for views disabled via core expressions
+		boolean isFiltered = (view == null) || WorkbenchActivityHelper.filterItem(view);
+
+		// E3 views can be detected by checking whether they use the compatibility layer
+		boolean isE3View = CompatibilityPart.COMPATIBILITY_VIEW_URI.equals(descriptor.getContributionURI());
+
+		// filtering can only be applied to E3 views, as activities don't exist in the Eclipse 4.
+		return isE3View && isFiltered;
 	}
 }
