@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -75,8 +75,12 @@ public class WorkbenchPreferencePage extends PreferencePage implements IWorkbenc
 
 	private Button showHeapStatusButton;
 
+	private Button showInlineRenameButton;
+
 	protected static int MAX_SAVE_INTERVAL = 9999;
 
+	private boolean renameModeInline;
+
 	@Override
 	protected Control createContents(Composite parent) {
 
@@ -98,14 +102,13 @@ public class WorkbenchPreferencePage extends PreferencePage implements IWorkbenc
 
 	/**
 	 * Create the buttons at the top of the preference page.
-	 * 
+	 *
 	 * @param composite
 	 */
 	protected void createSettings(Composite composite) {
 		createShowUserDialogPref(composite);
 		createStickyCyclePref(composite);
 		createHeapStatusPref(composite);
-		createSaveIntervalGroup(composite);
 	}
 
 	/**
@@ -164,7 +167,7 @@ public class WorkbenchPreferencePage extends PreferencePage implements IWorkbenc
 	 *
 	 * @param composite the Composite the group is created in.
 	 */
-	private void createSaveIntervalGroup(Composite composite) {
+	protected void createSaveIntervalGroup(Composite composite) {
 		Composite groupComposite = new Composite(composite, SWT.LEFT);
 		GridLayout layout = new GridLayout();
 		layout.numColumns = 2;
@@ -247,6 +250,18 @@ public class WorkbenchPreferencePage extends PreferencePage implements IWorkbenc
 				WorkbenchMessages.WorkbenchPreference_noEffectOnAllViews);
 	}
 
+	protected void createInlineRenamePref(Composite composite) {
+
+		showInlineRenameButton = new Button(composite, SWT.CHECK);
+		showInlineRenameButton.setText(WorkbenchMessages.WorkbenchPreference_inlineRename);
+		showInlineRenameButton.setToolTipText(WorkbenchMessages.WorkbenchPreference_inlineRename);
+
+		showInlineRenameButton.addSelectionListener(
+				widgetSelectedAdapter(e -> renameModeInline = showInlineRenameButton.getSelection()));
+
+		showInlineRenameButton.setSelection(renameModeInline);
+	}
+
 	private void selectClickMode(boolean singleClick) {
 		openOnSingleClick = singleClick;
 		selectOnHoverButton.setEnabled(openOnSingleClick);
@@ -333,6 +348,8 @@ public class WorkbenchPreferencePage extends PreferencePage implements IWorkbenc
 		openOnSingleClick = store.getBoolean(IPreferenceConstants.OPEN_ON_SINGLE_CLICK);
 		selectOnHover = store.getBoolean(IPreferenceConstants.SELECT_ON_HOVER);
 		openAfterDelay = store.getBoolean(IPreferenceConstants.OPEN_AFTER_DELAY);
+		readRenameModeFromPreferences();
+
 	}
 
 	/**
@@ -357,6 +374,10 @@ public class WorkbenchPreferencePage extends PreferencePage implements IWorkbenc
 		showHeapStatusButton.setSelection(
 				PrefUtil.getAPIPreferenceStore().getDefaultBoolean(IWorkbenchPreferenceConstants.SHOW_MEMORY_MONITOR));
 
+		String defaultRenameMode = store.getDefaultString(IWorkbenchPreferenceConstants.RESOURCE_RENAME_MODE);
+		renameModeInline = !IWorkbenchPreferenceConstants.RESOURCE_RENAME_MODE_DIALOG.equals(defaultRenameMode);
+		showInlineRenameButton.setSelection(renameModeInline);
+
 		super.performDefaults();
 	}
 
@@ -374,6 +395,13 @@ public class WorkbenchPreferencePage extends PreferencePage implements IWorkbenc
 		store.setValue(IPreferenceConstants.OPEN_AFTER_DELAY, openAfterDelay);
 		store.setValue(IPreferenceConstants.RUN_IN_BACKGROUND, showUserDialogButton.getSelection());
 		store.setValue(IPreferenceConstants.WORKBENCH_SAVE_INTERVAL, saveInterval.getIntValue());
+
+		String renameModeValue = IWorkbenchPreferenceConstants.RESOURCE_RENAME_MODE_INLINE;
+		if (!renameModeInline) {
+			renameModeValue = IWorkbenchPreferenceConstants.RESOURCE_RENAME_MODE_DIALOG;
+		}
+		store.setValue(IWorkbenchPreferenceConstants.RESOURCE_RENAME_MODE, renameModeValue);
+
 		PrefUtil.getAPIPreferenceStore().setValue(IWorkbenchPreferenceConstants.SHOW_MEMORY_MONITOR,
 				showHeapStatusButton.getSelection());
 		updateHeapStatus(showHeapStatusButton.getSelection());
@@ -395,7 +423,7 @@ public class WorkbenchPreferencePage extends PreferencePage implements IWorkbenc
 
 	/**
 	 * Show or hide the heap status based on selection.
-	 * 
+	 *
 	 * @param selection
 	 */
 	private void updateHeapStatus(boolean selection) {
@@ -407,4 +435,10 @@ public class WorkbenchPreferencePage extends PreferencePage implements IWorkbenc
 		}
 
 	}
+
+	private void readRenameModeFromPreferences() {
+		IPreferenceStore store = getPreferenceStore();
+		String renameMode = store.getString(IWorkbenchPreferenceConstants.RESOURCE_RENAME_MODE);
+		renameModeInline = !IWorkbenchPreferenceConstants.RESOURCE_RENAME_MODE_DIALOG.equals(renameMode);
+	}
 }
