@@ -19,12 +19,13 @@ package org.eclipse.ui.internal.progress;
 
 import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
 
-import com.ibm.icu.text.DateFormat;
 import java.net.URL;
+import java.text.DateFormat;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Optional;
 import org.eclipse.core.commands.ExecutionException;
 import org.eclipse.core.commands.NotEnabledException;
 import org.eclipse.core.commands.NotHandledException;
@@ -183,9 +184,9 @@ public class ProgressInfoItem extends Composite {
 	 * Create a new instance of the receiver with the specified parent, style and
 	 * info object/
 	 *
-	 * @param parent
-	 * @param style
-	 * @param progressInfo
+	 * @param parent       the parent composite
+	 * @param style        the style to use for the info item's composite
+	 * @param progressInfo the job element to represent
 	 */
 	public ProgressInfoItem(Composite parent, int style, JobTreeElement progressInfo) {
 		super(parent, style);
@@ -218,6 +219,7 @@ public class ProgressInfoItem extends Composite {
 		jobImageLabel.setLayoutData(imageData);
 
 		progressLabel = new Label(this, SWT.NONE);
+		progressLabel.addListener(SWT.Resize, event -> setMainText());
 		setMainText();
 
 		actionBar = new ToolBar(this, SWT.FLAT);
@@ -376,9 +378,8 @@ public class ProgressInfoItem extends Composite {
 	/**
 	 * Get the name and status for a jobInfo
 	 *
-	 * @param jobInfo
-	 *
-	 * @return String
+	 * @param jobInfo job element to get display string for
+	 * @return display string for job
 	 */
 	public String getJobNameAndStatus(JobInfo jobInfo) {
 
@@ -468,7 +469,8 @@ public class ProgressInfoItem extends Composite {
 					// There may be no task so we don't want to create it
 					// until we know for sure
 					for (JobInfo jobInfo : infos) {
-						if (jobInfo.hasTaskInfo() && jobInfo.getTaskInfo().totalWork == IProgressMonitor.UNKNOWN) {
+						Optional<TaskInfo> optionalInfo = jobInfo.getTaskInfo();
+						if (optionalInfo.isPresent() && optionalInfo.get().totalWork == IProgressMonitor.UNKNOWN) {
 							createProgressBar(SWT.INDETERMINATE);
 							break;
 						}
@@ -498,9 +500,9 @@ public class ProgressInfoItem extends Composite {
 
 		for (int i = 0; i < infos.length; i++) {
 			JobInfo jobInfo = infos[i];
-			TaskInfo taskInfo = jobInfo.getTaskInfo();
-
-			if (taskInfo != null) {
+			Optional<TaskInfo> optionalInfo = jobInfo.getTaskInfo();
+			if (optionalInfo.isPresent()) {
+				TaskInfo taskInfo = optionalInfo.get();
 
 				String taskString = taskInfo.getTaskName();
 				String subTaskString = null;
@@ -510,7 +512,7 @@ public class ProgressInfoItem extends Composite {
 				}
 
 				if (subTaskString != null) {
-					if (taskString == null || taskString.length() == 0) {
+					if (taskString == null || taskString.isEmpty()) {
 						taskString = subTaskString;
 					} else {
 						taskString = NLS.bind(ProgressMessages.JobInfo_DoneNoProgressMessage, taskString,
@@ -524,7 +526,7 @@ public class ProgressInfoItem extends Composite {
 				Job job = jobInfo.getJob();
 				IStatus result = job.getResult();
 
-				if (result == null || result.getMessage().length() == 0 && !info.isJobInfo()) {
+				if (result == null || result.getMessage().isEmpty() && !info.isJobInfo()) {
 					setLinkText(job, getJobNameAndStatus(jobInfo), i);
 				} else {
 					setLinkText(job, result.getMessage(), i);
@@ -615,9 +617,9 @@ public class ProgressInfoItem extends Composite {
 		if (info.hasChildren()) {
 			Object[] roots = ((GroupInfo) info).getChildren();
 			if (roots.length == 1 && roots[0] instanceof JobTreeElement) {
-				TaskInfo ti = ((JobInfo) roots[0]).getTaskInfo();
-				if (ti != null) {
-					return ti.getPercentDone();
+				Optional<TaskInfo> optionalInfo = ((JobInfo) roots[0]).getTaskInfo();
+				if (optionalInfo.isPresent()) {
+					return optionalInfo.get().getPercentDone();
 				}
 			}
 			return ((GroupInfo) info).getPercentDone();
@@ -678,8 +680,6 @@ public class ProgressInfoItem extends Composite {
 			linkData.top = new FormAttachment(progressBar, IDialogConstants.VERTICAL_SPACING);
 			linkData.left = new FormAttachment(progressBar, 0, SWT.LEFT);
 			linkData.right = new FormAttachment(progressBar, 0, SWT.RIGHT);
-			// Give an initial value so as to constrain the link shortening
-			linkData.width = 20;
 
 			taskEntries.get(0).setLayoutData(linkData);
 		}
@@ -703,15 +703,11 @@ public class ProgressInfoItem extends Composite {
 				linkData.top = new FormAttachment(top, IDialogConstants.VERTICAL_SPACING);
 				linkData.left = new FormAttachment(top, 0, SWT.LEFT);
 				linkData.right = new FormAttachment(top, 0, SWT.RIGHT);
-				// Give an initial value so as to constrain the link shortening
-				linkData.width = 20;
 			} else {
 				Link previous = taskEntries.get(index - 1);
 				linkData.top = new FormAttachment(previous, IDialogConstants.VERTICAL_SPACING);
 				linkData.left = new FormAttachment(previous, 0, SWT.LEFT);
 				linkData.right = new FormAttachment(previous, 0, SWT.RIGHT);
-				// Give an initial value so as to constrain the link shortening
-				linkData.width = 20;
 			}
 
 			link.setLayoutData(linkData);
@@ -754,6 +750,9 @@ public class ProgressInfoItem extends Composite {
 		updateText(taskString, link);
 	}
 
+	/**
+	 * The action/trigger associated with this progress item should be executed.
+	 */
 	public void executeTrigger() {
 		Object data = link.getData(TRIGGER_KEY);
 		if (data instanceof IAction) {
@@ -767,13 +766,9 @@ public class ProgressInfoItem extends Composite {
 			IStatus status = Status.OK_STATUS;
 			try {
 				handlerService.executeCommand((ParameterizedCommand) data, null);
-			} catch (ExecutionException e) {
-				status = new Status(IStatus.ERROR, PlatformUI.PLUGIN_ID, e.getMessage(), e);
-			} catch (NotDefinedException e) {
-				status = new Status(IStatus.ERROR, PlatformUI.PLUGIN_ID, e.getMessage(), e);
 			} catch (NotEnabledException e) {
 				status = new Status(IStatus.WARNING, PlatformUI.PLUGIN_ID, e.getMessage(), e);
-			} catch (NotHandledException e) {
+			} catch (ExecutionException | NotDefinedException | NotHandledException e) {
 				status = new Status(IStatus.ERROR, PlatformUI.PLUGIN_ID, e.getMessage(), e);
 			}
 
@@ -840,10 +835,10 @@ public class ProgressInfoItem extends Composite {
 	/**
 	 * Set the color base on the index
 	 *
-	 * @param i
+	 * @param row the item's index in presentation
 	 */
-	public void setColor(int i) {
-		currentIndex = i;
+	public void setColor(int row) {
+		currentIndex = row;
 
 		if (selected) {
 			setAllBackgrounds(getDisplay().getSystemColor(SWT.COLOR_LIST_SELECTION));
@@ -852,7 +847,7 @@ public class ProgressInfoItem extends Composite {
 		}
 
 		if (!isThemed) {
-			if (i % 2 == 0) {
+			if (row % 2 == 0) {
 				setAllBackgrounds(JFaceResources.getColorRegistry().get(DARK_COLOR_KEY));
 			} else {
 				setAllBackgrounds(getDisplay().getSystemColor(SWT.COLOR_LIST_BACKGROUND));
@@ -865,7 +860,7 @@ public class ProgressInfoItem extends Composite {
 	/**
 	 * Set the foreground of all widgets to the supplied color.
 	 *
-	 * @param color
+	 * @param color the new foreground color
 	 */
 	private void setAllForegrounds(Color color) {
 		setForeground(color);
@@ -881,7 +876,7 @@ public class ProgressInfoItem extends Composite {
 	/**
 	 * Set the background of all widgets to the supplied color.
 	 *
-	 * @param color
+	 * @param color the new background color
 	 */
 	private void setAllBackgrounds(Color color) {
 		setBackground(color);
@@ -898,7 +893,6 @@ public class ProgressInfoItem extends Composite {
 
 	/**
 	 * Set the focus to the button.
-	 *
 	 */
 	void setButtonFocus() {
 		actionBar.setFocus();
@@ -929,7 +923,7 @@ public class ProgressInfoItem extends Composite {
 	/**
 	 * Return whether or not the receiver is selected.
 	 *
-	 * @return boolean
+	 * @return receiver selected state
 	 */
 	boolean isSelected() {
 		return selected;
